//Clean and add weights
*global datain \Subsidy surveys\Analysis\
*global dataout \Subsidy surveys\Analysis\

global clist AGO ARG BGD BOL ECU EGY GHA IDN KAZ NGA PAK VNM

use "$datain\allrawdata_redup.dta", clear

**BRANCHING**

**Coding branches**

split br1, limit(2)
split br2, limit(2)
split br3, limit(2)
split br4, limit(2)

destring br12, gen(branch1)
destring br22, gen(branch2)
destring br32, gen(branch3)
destring br42, gen(branch4)
drop  br11 br12 br21 br22 br31 br32 br41 br42
egen branch = rowmax(branch1 branch2 branch3 branch4)

**Coding treatment groups**
gen part_treat = .
replace part_treat = 1 if branch>=1 & branch<=14

gen full_treat = .
replace full_treat = 1 if branch>=15 & branch<=28

gen prime_treat = 0 if part_treat==1
replace prime_treat = 1 if full_treat == 1
la def prime_treat 0 "Partial informtion" 1 "Full information"
la val prime_treat prime_treat

gen control = .
replace control = 1 if branch>=1 & branch<=8
replace control = 1 if branch>=15 & branch<=22

gen eff_treat = .
replace eff_treat = 1 if branch>=9 & branch<=10
replace eff_treat = 1 if branch>=23 & branch<=24

gen equ_treat = .
replace equ_treat = 1 if branch>=11 & branch<=12
replace equ_treat = 1 if branch>=25 & branch<=26

gen env_treat = .
replace env_treat = 1 if branch>=13 & branch<=14
replace env_treat = 1 if branch>=27 & branch<=28

gen main_treat = 0 if control == 1
replace main_treat = 1 if eff_treat == 1
replace main_treat = 2 if equ_treat == 1
replace main_treat = 3 if env_treat == 1
la def main_treat 0 "Control" 1 "Efficiency" 2 "Equity" 3 "Environment"
la val main_treat main_treat

gen any_treat = 0 if control == 1
replace any_treat = 1 if eff_treat == 1
replace any_treat = 1 if equ_treat == 1
replace any_treat = 1 if env_treat == 1
la def any_treat 0 "Control" 1 "Any of Efficiency/Equity/Environment"
la val any_treat any_treat

**PRE-TREATMENT VARIABLES**

**Coding background characteristics**

*Age*
gen age1824 = 0 if q1!=. & q1!= 10003
replace age1824 = 1 if q1 ==10004

*Sex*
gen male = 0 if q2!=.
replace male = 1 if q2 ==10007

**age/gender**
gen youngmen = 0 if q2!=.
replace youngmen = 1 if male==1 & age1824==1

gen oldmen = 0 if q2!=.
replace oldmen = 1 if male==1 & age1824==0

gen youngwomen = 0 if q2!=.
replace youngwomen = 1 if male==0 & age1824==1

gen oldwomen = 0 if q2!=.
replace oldwomen = 1 if male==0 & age1824==0

*Education*
gen edu_uni = 0 if q3!=.
replace edu_uni = 1 if q3 ==10013

*Location*
gen large_city = .
replace large_city = 0 if q4s =="Rest of the country"
replace large_city = 1 if q4s!="" & q4s ~="Rest of the country"

*Perceived relative position in income distribution*
gen pB40 = 0 if q5!=.
replace pB40 = 1 if q5== 10017
replace pB40 = 1 if q5== 10018

gen per_quintile = .
replace per_quintile = 1 if q5==10017
replace per_quintile = 2 if q5==10018
replace per_quintile = 3 if q5==10019
replace per_quintile = 4 if q5==10020
replace per_quintile = 5 if q5==10021

label define per_quintile1 1 "Poorest quintile" 2 "Second poorest quintile" 3 "Middle quintile" 4 "Second richest quintile" 5 "Richest quintile"

label values per_quintile per_quintile1 

*Actual relative position in income distribution*
egen act_quintile = rowmax(q7_1 q7_2 q7_3 q7_4 q7_5 q7_6 q7_7 q7_8)

label define act_quintile1 1 "Poorest quintile" 2 "Second poorest quintile" 3 "Middle quintile" 4 "Second richest quintile" 5 "Richest quintile"

label values act_quintile per_quintile1 

gen B40 = 0 if act_quintile!=.
replace B40 = 1 if act_quintile== 1
replace B40 = 1 if act_quintile== 2

**Cooking fuel**
gen elect = 0 if q8a!=.
replace elect = 1 if q8a== 10032

gen gas = 0 if q8a!=.
replace gas = 1 if q8a== 10033

**Transport**
gen pay_fuel = 0 if q9!=.
replace pay_fuel = 1 if q9== 10272
replace pay_fuel = 1 if q9== 10273

**Government capacity**
gen gov_cap = 0 if q11!=.
replace gov_cap = 1 if q11==10291
replace gov_cap = 1 if q11==10292

**Government trust**
gen trust = 0 if q12!=.
replace trust = 1 if q12==10047
replace trust = 1 if q12==10048

**Subsidies exist**
gen sub_exist = 0 if q14!=.
replace sub_exist = 1 if q14==10056

**Heterogenous treatment effects**

**Benefited from subsidies**
gen benefit = 0 if q16!=.
replace benefit = 1 if q16== 10295
replace benefit = 1 if q16== 10296
replace benefit = 1 if q16== 10297

**Right to receive subsidies**
gen right = 0 if q17!=.
replace right = 1 if q17== 10301
replace right = 1 if q17== 10302

**OUTCOME VARIABLES**

**Coding outcome variables**

**----------------------------------------------------
**Unconditional**

*Reduce*
gen reduce_d=0 if q18==10074
replace reduce_d =1 if q21==10338
replace reduce_d =1 if q21==10339

*Eliminate*
gen eliminate_d=0 if q18==10074
replace eliminate_d =1 if q22==10343
replace eliminate_d =1 if q22==10344


*Not keep*
gen not_keep_d=0 if q18==10074
replace not_keep_d =1 if q23==10350
replace not_keep_d =1 if q23==10351
replace not_keep_d =1 if q23==10352

*Reduce cost*
gen reduce_cost_d=0 if q18==10074
replace reduce_cost_d =1 if q24_10==10358 
replace reduce_cost_d =1 if q24_10==10359
replace reduce_cost_d =1 if q24_20==10363 
replace reduce_cost_d =1 if q24_20==10364 

*Unconditional support index*
egen z_reduce_d = std(reduce_d)
egen z_eliminate_d = std(eliminate_d)
egen z_not_keep_d = std(not_keep_d)
egen z_reduce_cost_d = std(reduce_cost_d)
*egen unconindex = rowmean(z_reduce_d z_eliminate_d z_not_keep_d z_reduce_cost_d)

**----------------------------------------------------
**Conditional**

**Cash all**
gen cash_all = .
replace cash_all=2 if q25_10a==10353|q25_20a==10368
replace cash_all=1 if q25_10a==10354|q25_20a==10369
replace cash_all=0 if q25_10a==10355|q25_20a==10370
replace cash_all=-1 if q25_10a==10356|q25_20a==10371
replace cash_all=-2 if q25_10a==10357|q25_20a==10372

gen cash_all_d = 0 if cash_all!=.
 replace cash_all_d = 1 if cash_all ==2
 replace cash_all_d = 1 if cash_all ==1
 
**Cash poor**
gen cash_poor =.
replace cash_poor=2 if q25_10b==10353|q25_20b==10368
replace cash_poor=1 if q25_10b==10354|q25_20b==10369
replace cash_poor=0 if q25_10b==10355|q25_20b==10370
replace cash_poor=-1 if q25_10b==10356|q25_20b==10371
replace cash_poor=-2 if q25_10b==10357|q25_20b==10372

gen cash_poor_d = 0 if cash_poor!=.
 replace cash_poor_d = 1 if cash_poor ==2
 replace cash_poor_d = 1 if cash_poor ==1
 
**Tax cuts**
gen tax_cuts=.
replace tax_cuts=2 if q25_10c==10353|q25_20c==10368
replace tax_cuts=1 if q25_10c==10354|q25_20c==10369
replace tax_cuts=0 if q25_10c==10355|q25_20c==10370
replace tax_cuts=-1 if q25_10c==10356|q25_20c==10371
replace tax_cuts=-2 if q25_10c==10357|q25_20c==10372

 gen tax_cuts_d = 0 if tax_cuts!=.
 replace tax_cuts_d = 1 if tax_cuts ==2
 replace tax_cuts_d = 1 if tax_cuts ==1
 
**Better schools, hospitals and roads**
gen spend=.
replace spend=2 if q25_10d==10353|q25_20d==10368
replace spend=1 if q25_10d==10354|q25_20d==10369
replace spend=0 if q25_10d==10355|q25_20d==10370
replace spend=-1 if q25_10d==10356|q25_20d==10371
replace spend=-2 if q25_10d==10357|q25_20d==10372

 gen spend_d = 0 if spend!=.
 replace spend_d = 1 if spend ==2
 replace spend_d = 1 if spend ==1
 
**Debt reduction**
gen debt = .
replace debt=2 if q25_10e==10353|q25_20e==10368
replace debt=1 if q25_10e==10354|q25_20e==10369
replace debt=0 if q25_10e==10355|q25_20e==10370
replace debt=-1 if q25_10e==10356|q25_20e==10371
replace debt=-2 if q25_10e==10357|q25_20e==10372

 gen debt_d = 0 if debt!=.
 replace debt_d = 1 if debt ==2
 replace debt_d = 1 if debt ==1
 
**Environment**
gen environ=.
replace environ=2 if q25_10f==10353|q25_20f==10368
replace environ=1 if q25_10f==10354|q25_20f==10369
replace environ=0 if q25_10f==10355|q25_20f==10370
replace environ=-1 if q25_10f==10356|q25_20f==10371
replace environ=-2 if q25_10f==10357|q25_20f==10372

 gen environ_d = 0 if environ!=.
 replace environ_d = 1 if environ ==2
 replace environ_d = 1 if environ ==1
 
**Quality and access**
gen quality=.
replace quality=2 if q25_10g==10353|q25_20g==10368
replace quality=1 if q25_10g==10354|q25_20g==10369
replace quality=0 if q25_10g==10355|q25_20g==10370
replace quality=-1 if q25_10g==10356|q25_20g==10371
replace quality=-2 if q25_10g==10357|q25_20g==10372

gen quality_d = 0 if quality!=.
replace quality_d = 1 if quality ==2
replace quality_d = 1 if quality ==1

**Anything else**
gen any_else = .
replace any_else = 0 if q26a_10==10122 | q26a_20==10136
replace any_else = 1 if q26a_10==10324 | q26a_20==10325

*Conditional support index*
egen z_cash_all_d = std(cash_all_d)
egen z_cash_poor_d = std(cash_poor_d)
egen z_tax_cuts_d = std(tax_cuts_d)
egen z_spend_d = std(spend_d)
egen z_debt_d = std(debt_d)
egen z_quality_d = std(quality_d)
egen z_environ_d = std(environ_d)
egen z_any_else = std(any_else)

egen conindex = rowmean(z_cash_all_d z_cash_poor_d z_tax_cuts_d z_spend_d z_debt_d z_environ_d z_quality_d z_any_else)

**REDUCE**
gen reduce = .
replace reduce=2 if q21==10338
replace reduce=1 if q21==10339
replace reduce=0 if q21==10340
replace reduce=-1 if q21==10341
replace reduce=-2 if q21==10342
**ELIMINATE**
gen eliminate=.
replace eliminate=2 if q22==10343
replace eliminate=1 if q22==10344
replace eliminate=0 if q22==10345
replace eliminate=-1 if q22==10346
replace eliminate=-2 if q22==10347

**REDUCE WITH COST**
gen reduce_cost=.
replace reduce_cost=2 if q24_10==10358|q24_20==10363
replace reduce_cost=1 if q24_10==10359|q24_20==10364
replace reduce_cost=0 if q24_10==10360|q24_20==10365
replace reduce_cost=-1 if q24_10==10361|q24_20==10366
replace reduce_cost=-2 if q24_10==10362|q24_20==10367

*Unconditional support index 2*
egen z_reduce = std(reduce)
egen z_eliminate = std(eliminate)
egen z_reduce_cost = std(reduce_cost)
egen unconindex2 = rowmean(z_reduce z_eliminate z_reduce_cost)

*Conditional support index 2*
egen z_cash_all = std(cash_all)
egen z_cash_poor = std(cash_poor)
egen z_tax_cuts = std(tax_cuts)
egen z_spend = std(spend)
egen z_debt = std(debt)
egen z_quality = std(quality)
egen z_environ = std(environ)

egen conindex2 = rowmean(z_cash_all z_cash_poor z_tax_cuts z_spend z_debt z_environ z_quality)
*drop unconindex
egen unconindex = rowmean(z_reduce_d z_eliminate_d z_reduce_cost_d)
/*
gen use_energy = .
replace use_energy = gas
replace use_energy = 1 if elect ==1
*/

gen use_energy = .
replace use_energy = pay_fuel if code=="AGO"
replace use_energy = 1 if elect ==1 & code=="AGO"

replace use_energy = pay_fuel if code=="ARG"
replace use_energy = 1 if elect ==1 & code=="ARG"
replace use_energy = 1 if gas ==1 & code=="ARG"

replace use_energy = gas if code=="BGD"
replace use_energy = 1 if elect ==1 & code=="BGD"

replace use_energy = pay_fuel if code=="BOL"
replace use_energy = 1 if elect ==1 & code=="BOL"

replace use_energy = pay_fuel if code=="ECU"
replace use_energy = 1 if elect ==1 & code=="ECU"

replace use_energy = pay_fuel if code=="EGY"
replace use_energy = 1 if elect ==1 & code=="EGY"

replace use_energy = elect if code=="GHA"

replace use_energy = pay_fuel if code=="IDN"
replace use_energy = 1 if elect ==1 & code=="IDN"

replace use_energy = gas if code=="KAZ"
replace use_energy = 1 if elect ==1 & code=="KAZ"
replace use_energy = 1 if pay_fuel ==1 & code=="KAZ"

replace use_energy = pay_fuel if code=="NGA"
replace use_energy = 1 if elect ==1 & code=="NGA"

replace use_energy = gas if code=="PAK"
replace use_energy = 1 if elect ==1 & code=="PAK"

replace use_energy = elect if code=="VNM"

**GENERATE CROSS COUNTRY VARIABLES**
*gen country_fuel = country if country_code !=3 & country_code !=6 & country_code !=7 & country_code !=11 & country_code !=12

*gen country_other = country if country_code ==3 | country_code ==6 | country_code ==7 | country_code ==11 | country_code ==12

gen fuel_countries = .
replace fuel_countries = 1 if code=="ARG" |code=="BOL"|code=="ECU"|code=="KAZ"|code=="IDN"|code=="AGO"|code=="NGA"
replace fuel_countries = 0 if code=="VNM"|code=="GHA"|code=="BGD"|code=="EGY"|code=="PAK"

label define fuel_countries1 0 "Electricity/Gas countries"  1 "Fuel countries" 
label values fuel_countries fuel_countries1 

**LABELS**
label variable reduce_d  "Reduce"
label variable eliminate_d  "Eliminate"
label variable reduce_cost_d  "Reduce with cost"
label variable cash_all_d  "Cash all HH"
label variable cash_poor_d  "Cash poor HH"
label variable tax_cuts_d  "Tax cuts"
label variable spend_d  "Gov spending"
label variable debt_d  "Public debt"
label variable environ_d  "Environment"
label variable quality_d  "Quality/access"

label variable age1824  "Aged between 18-24 years"
label variable male  "Male"
label variable youngmen  "Male aged between 18-24 years"
label variable oldmen  "Male aged 25 years +"
label variable youngwomen  "Female aged between 18-24 years"
label variable oldwomen  "Female aged 25 years +"
label variable edu_uni  "University level education"
label variable large_city  "Lives in Largest city/cities"
label variable pB40  "Perceived their HH to be in bottom 40 percent"
label variable per_quintile  "Perceived quintile in the distribution"
label variable B40  "HH in bottom 40 percent"
label variable act_quintile  "Actual quintile in the distribution"
label variable elect  "Electricity used for heating/cooking"
label variable gas  "Gas used for heating/cooking"
label variable pay_fuel  "Motor vehicle is main transport"
label variable gov_cap  "Believes government can do alot or some things to assist HH"
label variable trust  "Believes government can be trusted"
label variable sub_exist  "Believes subsidies exist"
label variable benefit  "Believes HH benefits greatly, alot or moderately from subsidies"
label variable right  "Believes HH greatly, alot or moderately has a right to receive subsidies"
label variable use_energy  "Uses subsidized energy source"
label variable fuel_countries  "Main type of energy by country"
/*
label variable country  "Country"

label variable country_code  "Country code"
label variable country_fuel  "Fuel countries"
label variable country_other  "Non-fuel countries"
*/

egen q25_10total=rowtotal(q25_10a q25_10b q25_10c q25_10d q25_10e q25_10f q25_10g), missing

egen q25_20total=rowtotal(q25_20a q25_20b q25_20c q25_20d q25_20e q25_20f q25_20g), missing
gen price_type = 10 if q25_10total>0 & q25_10total~=.
replace price_type = 20 if q25_20total>0 & q25_20total~=.

*gen age1824 = q1==10004 if q1~=.
gen age2534 = q1==10005 if q1~=. 
gen age1834 = q1==10004|q1==10005 if q1~=.
gen qt1 = act_quintile==1
gen qt2 = act_quintile==2
gen qt3 = act_quintile==3
gen qt4 = act_quintile==4
gen hh1 = q6==1 
gen hh2 = q6==2 
gen hh3 = q6==3 
gen hh4 = q6==4 
gen hh5 = q6==5 
gen hh6 = q6==6 
gen hh7 = q6==7 
replace q6 = 8 if q6==10029

gen qt12 = 0
replace qt12 = 1 if qt1==1|qt2==1

//Locations
gen loc1 = 0
gen loc2 = 0
gen loc12 = 0

//AGO
replace loc1 = 1 if q4s=="Luanda" & code=="AGO"
replace loc12 = loc1 if code=="AGO"

//ARG
replace loc1 = 1 if q4s=="Province of Buenos Aires or City of Buenos Aires" & code=="ARG"
replace loc2 = 1 if q4s=="Cordoba" & code=="ARG"
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="ARG"

//BGD 
replace loc1 = 1 if q4s=="Dhaka" & code=="BGD"
replace loc2 = 1 if q4s=="Chittagong" & code=="BDG"
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="BDG"

//BOL
replace loc1 = 1 if q4s=="Santa Cruz" & code=="BOL"
replace loc2 = 1 if q4s=="La Paz" & code=="BOL" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="BOL"

//ECU 
replace loc1 = 1 if q4s=="Guayas province" & code=="ECU"
replace loc2 = 1 if q4s=="Pichincha province" & code=="ECU" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="ECU"

//EGY 
replace loc1 = 1 if q4s=="Cairo Governate" & code=="EGY"
replace loc2 = 1 if q4s=="Alexandria Governate" & code=="EGY" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="EGY"

//GHA 
replace loc1 = 1 if q4s=="Greater Accra State" & code=="GHA"
replace loc12 = loc1 if code=="GHA"

//IDN 
replace loc1 = 1 if q4s=="Jakarta" & code=="IDN"
replace loc2 = 1 if q4s=="Rest of West Java" & code=="IDN" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="IDN"

//KAZ 
replace loc1 = 1 if q4s=="Almaty" & code=="KAZ"
replace loc2 = 1 if q4s=="East Kazakhstan" & code=="KAZ"
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="KAZ" 

//NGA 
replace loc1 = 1 if q4s=="Lagos" & code=="NGA"
replace loc2 = 1 if q4s=="Federal Capital Territory" & code=="NGA" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="NGA"

//PAK
replace loc1 = 1 if q4s=="Punjab" & code=="PAK"
replace loc2 = 1 if q4s=="Sindh" & code=="PAK" 
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="PAK"

//VNM
replace loc1 = 1 if q4s=="Ha Noi" & code=="VNM"
replace loc2 = 1 if q4s=="Ho Chi Minh" & code=="VNM"
replace loc12 = 1 if (loc1==1 | loc2==1) & code=="VNM"

** change to Buenos Aires

** Raking Weights

keep if Vstatus=="Complete"

* mat     male age1824 age2534 loc1  loc2   univ   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7
* mat1 [male] [age1824] [(combine loc1  loc2)] univ [(combine qt1 qt2)]

*AGO 
mat AGO = 0.47 \ 0.27 \ 0.28 \ 0.308 \ 0.07 \ 0.16 \ 0.176\0.197\0.211 \ 0.04 \ 0.069 \ 0.098 \ 0.13 \ 0.144 \ 0.139 \ 0.12
mat AGO1 = 0.47 \ 0.27 \ 0.308 \ 0.07 \ 0.336

*ARG \0.5627	\0.0584
mat ARG = 0.47 \ 0.15\ 0.20 \0.5627	\0.0584\ 0.37 \ 0.154\ 0.177\0.201\0.223 \ 0.085 \ 0.204 \ 0.21\0.236\0.135\0.062\0.032
mat ARG1 = 0.47 \ 0.15 \ 0.6211 \ 0.37 \ 0.331

*BGD\0.2435\0.2062
mat BGD = 0.48\0.19\0.27\0.2435 \0.042 \  0.179 \ 0.19\0.20\0.209 \ 0.011\0.086\0.191\0.274\0.211\0.116\0.055
mat BGD1 = 0.48 \ 0.19 \0.2435 \0.042 \  0.369

*BOL \ 0.2765\ 0.2683
mat BOL  = 0.48\0.18\0.23\ 0.2765\ 0.2683\0.304\ 0.155\0.176\0.194\0.22\0.077\0.17\0.21\0.235\0.16\0.08\0.03
mat BOL1  = 0.48\0.18\ 0.5448 \0.304\ 0.331

*ECU \ 0.2323\0.1642
mat ECU = 0.48 \ 0.19\0.23 \ 0.2323\0.1642\ 0.23\ 0.15\0.17\0.2\0.224 \0.05\0.128\0.17\0.22\0.17\0.09\0.067
mat ECU1 = 0.48 \ 0.19 \ 0.3965 \ 0.23\ 0.32

*EGY \ 0.1273	\0.0682
mat EGY = 0.5\0.18\0.19\ 0.1273	\0.0682\ 0.26\ 0.155\0.177\0.193\0.22\ 0.03\0.1\0.148\0.229\0.243\0.137\0.065 
mat EGY1 = 0.5\0.18\ .1955 \ 0.26\ 0.332

*GHA \ 0.1786
mat GHA = 0.46\0.23\0.26 \ 0.1786 \ 0.12 \0.16\0.176\0.189\0.213\0.114\0.096\0.125\0.152\0.155\0.11\0.084
mat GHA1 = 0.46 \ 0.23 \ 0.1786 \ 0.12 \ 0.336

*IDN \0.0402	\0.1849
mat IDN = 0.5\0.16\0.22\0.0402	\0.1849\0.143\0.186\0.192\0.198\0.206\0.027\0.11\0.227\0.295\0.188\0.092\0.035
mat IDN1 = 0.5\0.16\0.2251\0.143\.378

*KAZ \0.2191	\0.0817
mat KAZ = 0.44\0.12\0.22\0.2191	\0.0817\0.304\0.16\0.178\0.195\0.219\0.052\0.192\0.203\0.2\0.157\0.098\0.06
mat KAZ1 = 0.44\0.12\0.3008\0.304\0.338

*NGA \0.0798\0.0229
mat NGA = 0.48 \ 0.22\0.25\0.0798\0.0229\0.155\0.154\0.176\0.19\0.218\0.04\0.073\0.101\0.132\0.136\0.13\0.1
mat NGA1 = 0.48 \ 0.22\0.1027\0.155\0.33

*PAK \0.5578	\0.2341
mat PAK = 0.48\0.25\0.25\0.5578	\0.2341\0.155\0.154\0.178\0.2\0.218\.0042\0.028\0.059\0.101\0.137\0.152\0.128
mat PAK1 = 0.48\0.25\0.7920\0.155\0.332

*VNM  0.48 0.12    0.19    0.082 0.098  0.057  0.2 0.2 0.2 0.2 0.03 0.14 0.18 0.27 0.18 0.11 0.04 
mat VNM = 0.48 \0.12 \   0.19  \  0.082 \0.098 \ 0.057 \ 0.2 \0.2\ 0.2 \0.2\ 0.03 \0.14 \0.18\ 0.27\ 0.18\ 0.11\ 0.04
mat VNM1 = 0.48 \0.12 \  0.1794 \ 0.057 \ 0.4

//raking - method1
* mat1 [male] [age1824] [(combine loc1  loc2)] univ [(combine qt1 qt2)]

*AGO
wentropy male age1824 age2534 loc1 edu_uni qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6 hh7   if code=="AGO" , constraints(AGO) newweight(wt_rake1ago)
wentropy male age1824 loc12 edu_uni  qt12  if code=="AGO" , constraints(AGO1) newweight(wt_rake2ago)

*ARG
wentropy male age1824 age2534  loc1  loc2  edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="ARG" , constraints(ARG) newweight(wt_rake1arg)
wentropy male age1824 loc12 edu_uni qt12  if code=="ARG" , constraints(ARG1) newweight(wt_rake2arg)

*BGD loc2// loc2 does not work
wentropy male age1824 age2534 loc1     edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="BGD" , constraints(BGD) newweight(wt_rake1bgd)
wentropy male age1824 loc1 edu_uni qt12  if code=="BGD" , constraints(BGD1) newweight(wt_rake2bgd)

*BOL 
wentropy male age1824 age2534 loc1  loc2   edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="BOL" , constraints(BOL) newweight(wt_rake1bol)
wentropy male age1824  loc12     edu_uni   qt12  if code=="BOL" , constraints(BOL1) newweight(wt_rake2bol)

*ECU 
wentropy male age1824 age2534  loc1  loc2  edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="ECU" , constraints(ECU) newweight(wt_rake1ecu)
wentropy male age1824 loc12  edu_uni   qt12 if code=="ECU" , constraints(ECU1) newweight(wt_rake2ecu)

*EGY 
wentropy male age1824 age2534 loc1  loc2   edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="EGY" , constraints(EGY) newweight(wt_rake1egy)
wentropy male age1824 loc12   edu_uni   qt12 if code=="EGY" , constraints(EGY1) newweight(wt_rake2egy)

*GHA 
wentropy male age1824 age2534   loc1 edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="GHA" , constraints(GHA) newweight(wt_rake1gha)
wentropy male age1824   loc12 edu_uni   qt12  if code=="GHA" , constraints(GHA1) newweight(wt_rake2gha)

*IDN 
wentropy male age1824 age2534   loc1  loc2 edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="IDN" , constraints(IDN) newweight(wt_rake1idn)
wentropy male age1824  loc12   edu_uni   qt12 if code=="IDN" , constraints(IDN1) newweight(wt_rake2idn)

*KAZ 
wentropy male age1824 age2534  loc1  loc2  edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="KAZ" , constraints(KAZ) newweight(wt_rake1kaz)
wentropy male age1824 loc12  edu_uni   qt12 if code=="KAZ" , constraints(KAZ1) newweight(wt_rake2kaz)

*NGA 
wentropy male age1824 age2534  loc1  loc2 edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="NGA" , constraints(NGA) newweight(wt_rake1nga)
wentropy male age1824 loc12   edu_uni   qt12  if code=="NGA" , constraints(NGA1) newweight(wt_rake2nga)

*PAK
wentropy male age1824 age2534  loc1  loc2 edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="PAK" , constraints(PAK) newweight(wt_rake1pak)
wentropy male age1824  loc12   edu_uni   qt12  if code=="PAK" , constraints(PAK1) newweight(wt_rake2pak)

*VNM
wentropy male age1824 age2534 loc1  loc2   edu_uni   qt1 qt2 qt3 qt4 hh1  hh2  hh3  hh4  hh5  hh6  hh7 if code=="VNM" , constraints(VNM) newweight(wt_rake1vnm)
wentropy male age1824 loc12     edu_uni   qt12  if code=="VNM" , constraints(VNM1) newweight(wt_rake2vnm)

global clist AGO ARG BGD BOL ECU EGY GHA IDN KAZ NGA PAK VNM
gen wt_rake1= .
gen wt_rake2= .


foreach ct of global clist {
	replace wt_rake1 = wt_rake1`=lower("`ct'")' if code=="`ct'"
	replace wt_rake2 = wt_rake2`=lower("`ct'")' if code=="`ct'"
}

egen unit_upper1 = wpctile(wt_rake1),  p(99) by(code)
egen unit_lower1 = wpctile(wt_rake1),  p(1)  by(code) 

egen unit_upper2 = wpctile(wt_rake2),  p(99) by(code)
egen unit_lower2 = wpctile(wt_rake2),  p(1)  by(code) 

//trimming weights at 1st and 99th percentiles
gen wt_rake1t= wt_rake1
replace wt_rake1t = unit_upper1 if wt_rake1>unit_upper1 & wt_rake1~=.
replace wt_rake1t = unit_lower1 if wt_rake1<unit_lower1 & wt_rake1~=.

gen wt_rake2t= wt_rake2
replace wt_rake2t = unit_upper2 if wt_rake2>unit_upper2 & wt_rake2~=.
replace wt_rake2t = unit_lower2 if wt_rake2<unit_lower2 & wt_rake2~=.

**Descriptive statistics
la var wt_rake1 "raked weights on age, gender, location, edu, quintile, hhsize"
la var wt_rake2 "raked weights on dummies of age, gender, location, edu, quintile"
la var wt_rake1t "trimmed 1 and 99 percentiles of raked weights on age, gender, location, edu, quintile, hhsize"
la var wt_rake2t "trimmed 1 and 99 percentiles of raked weights on dummies of age, gender, location, edu, quintile"

global w wt_rake2
gen wt = 1
encode code, gen(code2)
compress
save "${dataclean}/allrawdata_weight.dta", replace
