**FULL DATA ANALYSIS**
/*This dofile produces Tables in Appendix C
This dofile: "2 - 2312_Appendix (tables)_v1.do"
Infile: "$dataclean\allrawdata_weight.dta"
Outfile:
- Tables C2, C3, C4, C5, C6, C7, C8, C9, C10
- Figures 
*/

***BEGIN DO FILE*** 
clear
version 17
set more off

**Open Data**
use "$dataclean\allrawdata_weight.dta", clear

**GENERATE CROSS COUNTRY VARIABLES**

encode code, generate(country_code)

gen country_fuel = code if country_code !=3 & country_code !=6 & country_code !=7 & country_code !=11 & country_code !=12

gen country_other = code if country_code ==3 | country_code ==6 | country_code ==7 | country_code ==11 | country_code ==12

gen country = country_code

gen price_10 = .
replace price_10 = 1 if q24_10!=.
replace price_10 = 0 if q24_20!=.

**TOTAL POPULATION IPW**

gen w_totpop = .

replace w_totpop = 0.3 if youngmen==1 & country_code==1
replace w_totpop = 0.9 if oldmen==1 & country_code==1
replace w_totpop = 1.4 if youngwomen==1 & country_code==1
replace w_totpop = 3.7 if oldwomen==1 & country_code==1

replace w_totpop = 1.4 if youngmen==1 & country_code==2
replace w_totpop = 1.0 if oldmen==1 & country_code==2
replace w_totpop = 1.3 if youngwomen==1 & country_code==2
replace w_totpop = 0.9 if oldwomen==1 & country_code==2

replace w_totpop = 0.3 if youngmen==1 & country_code==3
replace w_totpop = 0.9 if oldmen==1 & country_code==3
replace w_totpop = 0.8 if youngwomen==1 & country_code==3
replace w_totpop = 2.4 if oldwomen==1 & country_code==3

replace w_totpop = 0.6 if youngmen==1 & country_code==4
replace w_totpop = 0.9 if oldmen==1 & country_code==4
replace w_totpop = 1.0 if youngwomen==1 & country_code==4
replace w_totpop = 1.4 if oldwomen==1 & country_code==4

replace w_totpop = 0.8 if youngmen==1 & country_code==5
replace w_totpop = 1.0 if oldmen==1 & country_code==5
replace w_totpop = 0.9 if youngwomen==1 & country_code==5
replace w_totpop = 1.1 if oldwomen==1 & country_code==5

replace w_totpop = 0.6 if youngmen==1 & country_code==6
replace w_totpop = 1.1 if oldmen==1 & country_code==6
replace w_totpop = 0.6 if youngwomen==1 & country_code==6
replace w_totpop = 1.2 if oldwomen==1 & country_code==6

replace w_totpop = 0.6 if youngmen==1 & country_code==7
replace w_totpop = 0.9 if oldmen==1 & country_code==7
replace w_totpop = 0.9 if youngwomen==1 & country_code==7
replace w_totpop = 1.4 if oldwomen==1 & country_code==7

replace w_totpop = 0.6 if youngmen==1 & country_code==8
replace w_totpop = 1.1 if oldmen==1 & country_code==8
replace w_totpop = 0.6 if youngwomen==1 & country_code==8
replace w_totpop = 1.2 if oldwomen==1 & country_code==8

replace w_totpop = 0.6 if youngmen==1 & country_code==9
replace w_totpop = 0.9 if oldmen==1 & country_code==9
replace w_totpop = 0.8 if youngwomen==1 & country_code==9
replace w_totpop = 1.5 if oldwomen==1 & country_code==9

replace w_totpop = 0.5 if youngmen==1 & country_code==10
replace w_totpop = 1.0 if oldmen==1 & country_code==10
replace w_totpop = 0.8 if youngwomen==1 & country_code==10
replace w_totpop = 1.5 if oldwomen==1 & country_code==10

replace w_totpop = 0.6 if youngmen==1 & country_code==11
replace w_totpop = 0.8 if oldmen==1 & country_code==11
replace w_totpop = 1.1 if youngwomen==1 & country_code==11
replace w_totpop = 1.6 if oldwomen==1 & country_code==11

replace w_totpop = 0.6 if youngmen==1 & country_code==12
replace w_totpop = 1.0 if oldmen==1 & country_code==12
replace w_totpop = 0.7 if youngwomen==1 & country_code==12
replace w_totpop = 1.2 if oldwomen==1 & country_code==12

**LABELS**
		   
label define price_101 0 "20% price increase"  1 "10% price increase" 
label values price_10 price_101 

label define gov_cap1 0 "Government not capable"  1 "Government capable" 
label values gov_cap gov_cap1 

label define trust1 0 "Do not trust government"  1 "Trust government" 
label values trust trust1 

label define sub_exist1 0 "Energy subsidies do not exist"  1 "Energy subsidies exist" 
label values sub_exist sub_exist1 
 
label define benefit1 0 "Do not benefit from energy subsidies"  1 "Benefit from energy subsidies" 
label values benefit benefit1 

label define right1 0 "Energy subsidies are not a right"  1 "Energy subsidies are a right" 
label values right right1 
 
label define use_energy1 0 "Do not use subsidised energy"  1 "Use subsidised energy" 
label values use_energy use_energy1 
 
label define prime_treat1 0 "Partial primer"  1 "Full primer" 
label values prime_treat prime_treat1 

label define B401 0 "Top 60%"  1 "Bottom 40%" 
label values B40 B401 
 
**RECODE TREATMENT VARIABLES**  
drop if eff_treat == 1 & country_code==1

label define main_treat1 0 "Control"  1 "Efficiency" 2 "Equity" 3 "Environment"
label values main_treat main_treat1 

drop eff_treat equ_treat env_treat 

gen eff_treat=.
replace eff_treat = 0 if main_treat==0
replace eff_treat = 1 if main_treat==1

gen equ_treat=.
replace equ_treat = 0 if main_treat==0
replace equ_treat = 1 if main_treat==2

gen env_treat=.
replace env_treat = 0 if main_treat==0
replace env_treat = 1 if main_treat==3
  
gen equ_env_treat=.
replace equ_env_treat = 0 if main_treat==0
replace equ_env_treat = 1 if main_treat==2
replace equ_env_treat = 1 if main_treat==3

label define eff_treat1 0 "Control"  1 "Efficiency Treatment" 
label values eff_treat eff_treat1 

label define equ_treat1 0 "Control"  1 "Equity Treatment" 
label values equ_treat equ_treat1 

label define env_treat1 0 "Control"  1 "Environment Treatment" 
label values env_treat env_treat1 

replace any_treat = equ_env_treat if country_code==1

**RECODE BACKGROUND VARIBLE**

gen per_place=.
replace per_place = 1 if per_quintile==1
replace per_place = 1 if per_quintile==2
replace per_place = 2 if per_quintile==3
replace per_place = 3 if per_quintile==4
replace per_place = 3 if per_quintile==5

label define per_place1 1 "Perceive Poor" 2 "Perceive Middle class"  3 "Perceive Rich" 
label values per_place per_place1 

gen pmid20=0
replace pmid20=1 if per_quintile==3

label define pmid201 0 "Other"  1 "Middle 20%" 
label values pmid20 pmid201 
		            
label variable pmid20  "Perceived their HH to be in the middle 20 percent"

gen bias=0
replace bias=1 if q30==10125

label define male1 0 "Female"  1 "Male" 
label values male male1 

**Recode indexes**
drop unconindex

egen z_reduce_d2 = std(reduce_d)

egen z_eliminate_d2 = std(eliminate_d)

egen z_reduce_cost_d2 = std(reduce_cost_d)

egen unconindex = rowmean(z_reduce_d2 z_eliminate_d2 z_reduce_cost_d2)

drop conindex

egen z_cash_all_d2 = std(cash_all_d)

egen z_cash_poor_d2 = std(cash_poor_d)

egen z_tax_cuts_d2 = std(tax_cuts_d)

egen z_spend_d2 = std(spend_d)

egen z_debt_d2 = std(debt_d)

egen z_quality_d2 = std(quality_d)

egen z_environ_d2 = std(environ_d)

egen z_any_else2 = std(any_else)

egen conindex = rowmean(z_cash_all_d2 z_cash_poor_d2 z_tax_cuts_d2 z_spend_d2 z_debt_d2 z_environ_d2 z_quality_d2 z_any_else2)

egen q26a = rowtotal (q26a_10 q26a_20)

**APPENDIX TABLES**

**APPENDIX**

**Table C2 - Weighted Treatment effects on unconditional support***

**Any treat**

reghdfe reduce_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m01

reghdfe eliminate_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m02

reghdfe reduce_cost_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m04

reghdfe unconindex any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC2.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
keep(any_treat) varlabels(any_treat "Any treatment") f nonumbers mtitles("Reduce" "Eliminate" "Reduce with Cost" "Index") noobs replace

**Main treat**

reghdfe reduce_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m01

reghdfe eliminate_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m02

reghdfe reduce_cost_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m04

reghdfe unconindex i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC2.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  stats(p_diff1 p_diff2 p_diff3) ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(1.main_treat "Efficiency treatment" 2.main_treat "Equity treatment" 3.main_treat "Environment treatment") f nonumbers nomtitles noobs

**Control mean**

reghdfe reduce_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m01

reghdfe eliminate_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m02

reghdfe reduce_cost_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m04

esttab m01 m02 m04 using "${tables}\\TableC2.tex", append cells(b(fmt(3)))   ///  
keep(_cons) varlabels(_cons "Control Mean") f nonumbers nomtitles 

**Table C3 - Treatment effects on unconditional support***

**Any treat**

reghdfe cash_all_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m01

reghdfe cash_poor_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m02

reghdfe tax_cuts_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m03

reghdfe spend_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m04

reghdfe debt_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m05

reghdfe environ_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m06

reghdfe quality_d any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m07

reghdfe any_else any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m08

reghdfe conindex any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC3.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
keep(any_treat) varlabels(any_treat "Any treatment") f nonumbers mtitles("cash_all" "cash_poor" "tax_cuts" "spend" "debt" "environ" "quality" "any_else" "index") noobs replace

**Main treatment**

reghdfe cash_all_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m01

reghdfe cash_poor_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m02

reghdfe tax_cuts_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m03

reghdfe spend_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m04

reghdfe debt_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m05

reghdfe environ_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m06

reghdfe quality_d i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m07

reghdfe any_else i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m08

reghdfe conindex i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist [aw=w_totpop], a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC3.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  stats(p_diff1 p_diff2 p_diff3) ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(1.main_treat "Efficiency treatment" 2.main_treat "Equity treatment" 3.main_treat "Environment treatment") f nonumbers nomtitles noobs

**Control mean**

reghdfe cash_all_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m01

reghdfe cash_poor_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m02

reghdfe tax_cuts_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m03

reghdfe spend_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m04

reghdfe debt_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m05

reghdfe environ_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m06

reghdfe quality_d any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m07

reghdfe any_else any_treat [aw=w_totpop], a(country_code) vce(cluster country_code)  

estimates store m08

esttab m01 m02 m03 m04 m05 m06 m07 m08 using "${tables}\\TableC3.tex", append cells(b(fmt(3)))  ///  
keep(_cons) varlabels(_cons "Control Mean") f nonumbers nomtitles 

**Table C4 - Heterogenous treatment effects on unconditional support (SELF INTEREST)***

**Benefit**

reghdfe reduce_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC4.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("Reduce" "Eliminate" "Reduce with Cost" "Index") noobs replace

**Use energy**

reghdfe reduce_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC4.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**B40 percent of income distribution**

reghdfe reduce_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC4.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C5 - Heterogenous reatment effects on unconditional support***

**Benefit**

reghdfe cash_all_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##benefit youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC5.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("cash_all" "cash_poor" "tax_cuts" "spend" "debt" "environ" "quality" "any_else" "index") noobs replace

**Pay for fuel**

reghdfe cash_all_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##use_energy youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC5.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**Bottom 40 percent**

reghdfe cash_all_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##B40 youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC5.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C6 - Heterogenous treatment effects on unconditional support (SOCIAL CONTRACT)***

**Trust**

reghdfe reduce_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC6.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("Reduce" "Eliminate" "Reduce with Cost" "Index") noobs replace

**Capable**

reghdfe reduce_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC6.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**Right**

reghdfe reduce_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC6.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C7 - Heterogenous treatment effects on unconditional support (SOCIAL CONTRACT)***

**Trust**

reghdfe cash_all_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##trust youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC7.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("cash_all" "cash_poor" "tax_cuts" "spend" "debt" "environ" "quality" "any_else" "index") noobs replace

**Government capable**

reghdfe cash_all_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##gov_cap youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC7.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**Right**

reghdfe cash_all_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##right youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC7.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C8 - Heterogenous treatment effects on unconditional support (KNOWLEDGE)***

**Exist**

reghdfe reduce_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC8.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("Reduce" "Eliminate" "Reduce with Cost" "Index") noobs replace

**Education**

reghdfe reduce_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC8.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**Primer**

reghdfe reduce_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe eliminate_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe reduce_cost_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe unconindex any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

esttab m01 m02 m04 m05 using "${tables}\\TableC8.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C9 - Heterogenous treatment effects on unconditional support (KNOWLEDGE)***

**Exist**

reghdfe cash_all_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##sub_exist youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap sub_exist sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC9.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap _cons) varlabels(any_treat "Any treatment") f nonumbers mtitles("cash_all" "cash_poor" "tax_cuts" "spend" "debt" "environ" "quality" "any_else" "index") noobs replace

**Education**

reghdfe cash_all_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##edu_uni youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel edu_uni trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC9.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles noobs

**Primer**

reghdfe cash_all_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m01

reghdfe cash_poor_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m02

reghdfe tax_cuts_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m03

reghdfe spend_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m04

reghdfe debt_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m05

reghdfe environ_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m06

reghdfe quality_d any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m07

reghdfe any_else any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m08

reghdfe conindex any_treat##prime_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country) vce(cluster country)  

estimates store m09

esttab m01 m02 m03 m04 m05 m06 m07 m08 m09 using "${tables}\\TableC9.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(any_treat "Any treatment") f nonumbers nomtitles 

**Table C10 - Survey bias***

**Any treat**

reghdfe bias any_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country_code) vce(cluster country_code)  

estimates store m01

esttab m01 using "${tables}\\TableC10.tex", cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  ///  
keep(any_treat) varlabels(any_treat "Any treatment") f nonumbers mtitles("Bias") noobs replace

**Main treat**

reghdfe bias i.main_treat youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist, a(country_code) vce(cluster country_code)  

test 1.main_treat = 2.main_treat 

estadd scalar p_diff1 = r(p)

test 1.main_treat = 3.main_treat 

estadd scalar p_diff2 = r(p)

test 2.main_treat = 3.main_treat 

estadd scalar p_diff3 = r(p)

estimates store m01

esttab m01 using "${tables}\\TableC10.tex", append cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01)  stats(p_diff1 p_diff2 p_diff3) ///  
drop(youngmen oldmen youngwomen oldwomen edu_uni large_city pB40 per_quintile act_quintile B40 elect gas pay_fuel gov_cap trust sub_exist _cons) varlabels(1.main_treat "Efficiency treatment" 2.main_treat "Equity treatment" 3.main_treat "Environment treatment") f nonumbers nomtitles noobs

**Control mean**
reghdfe bias any_treat, a(country_code) vce(cluster country_code)  

estimates store m01

esttab m01 using "${tables}\\TableC10.tex", append cells(b(fmt(3)))   ///  
keep(_cons) varlabels(_cons "Control Mean") f nonumbers nomtitles 

**APPENDIX Figures**

**Figure A3**

gen p = prime_treat
  
label define p1 0 "Partial primer"  1 "Full primer" 

label values p p1   
  
cibar benefit, over1(p) over2(code2) gr(ytitle(Share of respondents) leg(pos(6) col(2)))

graph export "${figures}\FigureA3.png", replace	  

**Figure C9**
reghdfe pmid male age1824 edu_uni large_city B40 use_energy gov_cap trust right benefit sub_exist, a(country_code) vce(cluster country_code)

est store pmid

coefplot pmid, title(Perceived Middle Quintile, span size(medium)) label(labsize(small)) ///      
      || , norecycle drop(_cons *.code2) xline(0)  byopts(legend(position(5))) sort(, descending) 
	  
graph export "${figures}\FigureC9.png", wid(3000) replace

	  
**Figure C7**
egen t1 = rowtotal(cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d), missing
gen t2 = t1==7
replace t1 = 1 if t1>0 & t1~=.

egen t1_v2 = rowtotal(cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d), missing
	
label variable edu_uni  "University"

label variable large_city  "Major city"

label variable pB40  "Perceive B40%"

label variable B40  "Bottom 40%"

label variable use_energy  "Use energy"

label variable gov_cap  "Capacity"

label variable trust  "Trust"

label variable sub_exist  "Subsidies exist"

label variable benefit  "Benefit"

label variable right  "Right"

label variable age1824  "18-24 years old"

label variable pmid20  "Perceive M20%"

reghdfe t1_v2 male age1824 edu_uni large_city B40 pB40 pmid20 use_energy gov_cap trust right benefit sub_exist if main_treat==0, a(country_code) vce(cluster country_code)

est store est_t1_v2_all

reghdfe t1_v2 male age1824 edu_uni large_city B40 pB40 pmid20 use_energy gov_cap trust right benefit sub_exist if main_treat==0 & reduce_cost_d==0 [aw=w_totpop], a(country_code) vce(cluster country_code)

est store est_t1_v2_nouncon

coefplot est_t1_v2_all, bylabel(All respondents) || ///
		est_t1_v2_nouncon, bylabel(Respondents w/o uncon. support) || ///
		, norecycle drop(_cons) xline(0) byopts(xrescale legend(off) col(7)) sort(, descending)

graph export "${figures}\FigureC7.png", replace		