//FIG and TABLES for WP paper
/*
This dofile: "3 - basic stat WP paper.do"
Infile: "$dataclean\allrawdata_weight.dta"
Outfile:
- Data (ID_opentext.dta) for text analysis
- Tables A1, A2
- Figures 2, 3, 4, 6, 7, 8, A4, C4, C5, C6
*/

clear
version 17
tempfile datattest
save `datattest', replace emptyok

global clist AGO ARG BGD BOL ECU EGY GHA IDN KAZ NGA PAK VNM

use "$dataclean\allrawdata_weight.dta", clear

la def large_city 1 "Large cities" 0 "Rest of country"
la val large_city large_city
la def B40 1 "HH in bottom 40%" 0 "HH in top 60%"
la val B40 pB40 B40 
la def pay_fuel 1 "Motor vehicle and motorbike" 0 "Other shared transportation"
la val pay_fuel pay_fuel
la def age1824 1 "Aged between 18-24 years" 0 "Aged 25 years and older"
la val age1824 age1824
la var age1834 "Aged between 18-34 years"
la def age1834 1 "Aged between 18-34 years" 0 "Aged 35 years and older"
la val age1834 age1834
gen per_place=.
replace per_place=1 if per_quintile==1
replace per_place=1 if per_quintile==2
replace per_place=2 if per_quintile==3
replace per_place=3 if per_quintile==4
replace per_place=3 if per_quintile==5
la def per_place 1 "Bottom 40%" 2 "Middle quintile" 3 "Top 40%"
la val per_place per_place
gen per_place1 = per_place==1
la var per_place1 "Perceived their HH to be in bottom 40 percent"
gen per_place2 = per_place==2
la var per_place2 "Perceived their HH to be in middle quintile"
clonevar pmid20 = per_place2

la var gov_cap "Believes Govt can do to assist HH"
la var benefit "Believes HH benefits from subsidies"
la var right "Believes HH has a right to receive subsidies"
la def trust 1 "Agree govt. could be trusted" 0 "Disagree govt. could be trusted"
la val trust trust
la def price_type 10 "Increase 10%" 20 "Increase 20%"
la val price_type price_type

la def branch  1 "Branch 1" 2 "Branch 2" 3 "Branch 3" 4 "Branch 4" 5 "Branch 5" 6 "Branch 6" 7 "Branch 7" 8 "Branch 8" 9 "Branch 9" 10 "Branch 10" 11 "Branch 11" 12 "Branch 12" 13 "Branch 13" 14 "Branch 14" 15 "Branch 15" 16 "Branch 16" 17 "Branch 17" 18 "Branch 18" 19 "Branch 19" 20 "Branch 20" 21 "Branch 21" 22 "Branch 22" 23 "Branch 23" 24 "Branch 24" 25 "Branch 25" 26 "Branch 26" 27 "Branch 27" 28 "Branch 28"
la val branch branch

la def male 1 "Male" 0 "Female"
la val male male

gen eff_d = (q20a==10076|q20a==10077) if q20a~=.
gen equ_d = (q20b==10081|q20b==10082) if q20b~=.
gen env_d = (q20c==10181|q20c==10182) if q20c~=.
la var eff_d "Cost more than healthcare"
la var equ_d "Mainly benefit richer HHs"
la var env_d "Damage the environment"

label variable edu_uni  "University"
label variable large_city  "Major city"
label variable pB40  "Perceive Poor"
label variable B40  "Bottom 40%"
label variable use_energy  "Use energy"
label variable gov_cap  "Capacity"
label variable trust  "Trust"
label variable sub_exist  "Subsidies exist"
label variable benefit  "Benefit"
label variable right  "Right"
label variable age1824  "18-24 years old"
label variable age1834  "18-34 years old"
label variable pmid20  "Perceive Middle Class"
label variable per_place1  "Perceive B40%"
label variable per_place2  "Perceive M20%"

//AGO ARG BGD BOL ECU EGY GHA IDN KAZ NGA PAK VNM
gen code3 = ""
replace code3 = "Angola" if code=="AGO"
replace code3 = "Argentina" if code=="ARG"
replace code3 = "Bangladesh" if code=="BGD"
replace code3 = "Bolivia" if code=="BOL"
replace code3 = "Ecuador" if code=="ECU"
replace code3 = "Egypt, Arab Rep." if code=="EGY"
replace code3 = "Ghana" if code=="GHA"
replace code3 = "Indonesia" if code=="IDN"
replace code3 = "Kazakhstan" if code=="KAZ"
replace code3 = "Nigeria" if code=="NGA"
replace code3 = "Pakistan" if code=="PAK"
replace code3 = "Viet Nam" if code=="VNM"

** Setting
global w wt_rake2t
*bar(1,color(green)) bar(2,color(red))
set scheme s1color

** Distribution with weights

tab code q1 [aw=$w], row nof
tab code q1 , row nof

tab code q2 [aw=$w], row nof
tab code q2 , row nof

tab code edu_uni [aw=$w], row nof
tab code edu_uni , row nof

table (code) [aw=$w], statistic(mean male edu_uni age1824 age2534)
table (code) , statistic(mean male edu_uni age1824 age2534)

tab code per_quintile [aw=$w], row nof
tab code per_quintile , row nof

tab code act_quintile [aw=$w], row nof
tab code act_quintile , row nof

tab code q6 [aw=$w], row nof
tab code q6 , row nof

foreach ctry of global clist {
	dis "`ctry'"
	ta q4s if code=="`ctry'"
	ta q4s [aw=wt_rake1] if code=="`ctry'"
}

ta code q8a [aw=$w], nof row
ta code q8a, nof row

ta code q8b [aw=$w], nof row
ta code q8b, nof row

ta code q9 [aw=$w], nof row
ta code q9, nof row

** income values
gen income_val = .
local AGO AGO 14000	19000.5	31000.5	51000.5	64001
local ARG ARG 40000 50000.5 75000.5 115000.5 140001
local BGD BGD 3000 3500.5 4500.5 6000.5 7001
local BOL BOL 700 850.5 1250.5 1900.5 2301
local ECU ECU 100 125.5 185.5 285.5 351
local EGY EGY 1000 1125.5 1425.5 1850.5 2101
local GHA GHA 200 300.5 500.5 750.5 901
local IDN IDN 600000 725500 1025500 1450500 1701000
local KAZ KAZ 45000 51000.5 64000.5 84000.5 97001
local NGA NGA 14000 17000.5 24000.5 34000.5 40001
local PAK PAK 5500 6250.5 7800.5 10300.5 12001
local VNM VNM 1800000 2200500 3050500 4350500 5201000

qui foreach ctry of global clist {
	tokenize ``ctry''
	forv j=2(1)6 {
		forv i=1(1)8 {
			*dis `"replace income_val = ``j''*`i' if act_quintile==`=`j'-1' & q6==`i' & code=="`1'" "'
			replace income_val = ``j''*`i' if act_quintile==`=`j'-1' & q6==`i' & code=="`1'"
		}
	}	
}

qui {
	for var q10_elec q10_gas q10_fuel q10_other: replace X = 0 if X<0
	*rebase to 2017 PPP
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/2.153634857/107.26999 if code=="AGO"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/4.345534554/10.80794 if code=="ARG"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.338890577/29.514082 if code=="BGD"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.077579603/2.6119339 if code=="BOL"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.032956114/.57450336 if code=="ECU"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.571891231/4.8435497 if code=="EGY"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.83216791/1.7509922 if code=="GHA"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.146919298/5089.686 if code=="IDN"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.287173572/125.26337 if code=="KAZ"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.965534003/123.67238 if code=="NGA"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.673673325/33.250732 if code=="PAK"
	for var q10_elec q10_gas q10_fuel q10_other income_val: replace X = X/1.15409708/7807.6123 if code=="VNM"
}

*outlier

egen elec_99 = wpctile(q10_elec),  p(90) by(code)
egen gas_99 = wpctile(q10_gas),  p(90) by(code)
egen fuel_99 = wpctile(q10_fuel),  p(90) by(code)
egen other_99 = wpctile(q10_other),  p(90) by(code)

replace q10_elec = elec_99 if q10_elec>elec_99 & q10_elec!=.
replace q10_gas = gas_99 if q10_gas>gas_99 & q10_gas!=.
replace q10_fuel = fuel_99 if q10_fuel>fuel_99 & q10_fuel!=.
replace q10_other = other_99 if q10_other>other_99 & q10_other!=.
drop elec_99 gas_99 fuel_99 other_99

*bys code: winsor q10_elec q10_gas q10_fuel q10_other, cuts (10 90) suffix(_new) 

gen double sh_elec = q10_elec/income_val if q10_elec~=.
gen double sh_gas = q10_gas/income_val if q10_gas~=.
gen double sh_fuel = q10_fuel/income_val if q10_fuel~=.
gen double sh_other = q10_other/income_val if q10_other~=.

table code [aw=$w], statistic(mean sh_*)

egen selec_99 = wpctile(sh_elec),  p(95) by(code)
egen sgas_99 = wpctile(sh_gas),  p(95) by(code)
egen sfuel_99 = wpctile(sh_fuel),  p(94) by(code)
egen sother_99 = wpctile(sh_other),  p(95) by(code)

replace sh_elec = selec_99 if sh_elec>selec_99 & sh_elec!=.
replace sh_gas = sgas_99 if sh_gas>sgas_99 & sh_gas!=.
replace sh_fuel = sfuel_99 if sh_fuel>sfuel_99 & sh_fuel!=.
replace sh_other = sother_99 if sh_other>sother_99 & sh_other!=.
drop selec_99 sgas_99 sfuel_99 sother_99

table code [aw=$w], statistic(mean sh_*)
egen sh_energy = rowtotal(sh_elec sh_gas sh_fuel sh_other), missing

//creating deciles based on share of energy 
egen dec_sh_energy = xtile(sh_energy), by(code) nq(10) w($w)
la var dec_sh_energy "Deciles on energy shares"

** Unconditional and conditional programs
qui {
	gen q26a = 0
	replace q26a = 1 if (q26a_10==10324 | q26a_20==10325)
	egen t1 = rowtotal(cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d), missing
	gen t2 = t1==7
	replace t1 = 1 if t1>0 & t1~=.
	
	replace t1 = 1 if q26a==1 & t1==0 //add additional support
	
	gen resp_type =.
	replace resp_type =1 if reduce_cost_d==1 & t1==1
	replace resp_type =2 if reduce_cost_d==0 & t1==1
	replace resp_type =3 if reduce_cost_d==1 & t1==0
	replace resp_type =4 if reduce_cost_d==0 & t1==0
	la def resp_type 1 "Both support" 2 "Only conditional" 3 "Only unconditional" 4 "No support"
	la val resp_type resp_type

	gen resp_type1 =.
	replace resp_type1 =1 if reduce_cost_d==1 & t1==1
	replace resp_type1 =2 if reduce_cost_d==0 & (spend_d==1 | quality_d==1)
	replace resp_type1 =3 if reduce_cost_d==0 & t1==1 & spend_d!=1 & quality_d!=1
	replace resp_type1 =4 if reduce_cost_d==1 & t1==0
	replace resp_type1 =5 if reduce_cost_d==0 & t1==0
	la def resp_type1 1 "Both support" 2 "Cond. support (spend and/or quality)" 3 "Cond. support (other)" 4 "Only uncond." 5 "No support"
	la val resp_type1 resp_type1
	
	gen resp_type3 =.
	replace resp_type3 =1 if reduce_cost_d==1 & t1==1
	replace resp_type3 =2 if reduce_cost_d==0 & (spend_d==1)	
	replace resp_type3 =3 if reduce_cost_d==0 & t1==1 & spend_d!=1 
	replace resp_type3 =4 if reduce_cost_d==1 & t1==0
	replace resp_type3 =5 if reduce_cost_d==0 & t1==0
	
	gen resp_type2 =.
	replace resp_type2 =1 if reduce_cost_d==1 & t2==1
	replace resp_type2 =2 if reduce_cost_d==0 & t2==1
	replace resp_type2 =3 if reduce_cost_d==1 & t2==0
	replace resp_type2 =4 if reduce_cost_d==0 & t2==0
	la val resp_type2 resp_type
	
}

** marginal programs
gen allprog = string(reduce_cost_d) +string(cash_all_d) + string(cash_poor_d) + string(tax_cuts_d) + string(spend_d) + string(debt_d) + string(environ_d) + string(quality_d) 

//Cond. and uncond. support profiling
gen resp_type_1 = 100*(resp_type==1)
gen resp_type_2 = 100*(resp_type==2)
gen resp_type_3 = 100*(resp_type==3)
gen resp_type_4 = 100*(resp_type==4)

gen resp_type1_1 = 100*(resp_type1==1)
gen resp_type1_2 = 100*(resp_type1==2)
gen resp_type1_3 = 100*(resp_type1==3)
gen resp_type1_4 = 100*(resp_type1==4|resp_type1==5)
*gen resp_type1_5 = 100*(resp_type1==5)

la var resp_type1_1 "Both support"
la var resp_type1_2 "Cond. support (spend and/or quality)"
la var resp_type1_3 "Cond. support (other)"
la var resp_type1_4 "No support"

gen resp_type3_1 = 100*(resp_type3==1)
gen resp_type3_2 = 100*(resp_type3==2)
gen resp_type3_3 = 100*(resp_type3==3)
gen resp_type3_4 = 100*(resp_type3==4|resp_type3==5)

la var resp_type3_1 "Both support"
la var resp_type3_2 "Cond. support (spend)"
la var resp_type3_3 "Cond. support (other)"
la var resp_type3_4 "No support"

* the outcome variable in the first chart is a dummy taking the value of 1 if the respond had both unconditional and conditional support and 0 otherwise
gen both_support_d = resp_type==1

* the outcome variable in the second chart is a dummy taking the value of 1 if the respond had only conditional support and 0 otherwise
gen uncond_d = resp_type==3

* respondents who did not answer on policy options but do answer open text
egen t1x = rowtotal(cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d), missing
replace t1x = 1 if t1x>0 & t1x~=.
ta t1x q26a
gen open_resp = 0
replace open_resp = 1 if t1x==0 & q26a==1
la var open_resp "Respondents who did not answer policy options but answered open text"
drop t1x
tempfile data1s
save `data1s', replace

* Save data for the open text analysis
keep Vrid q1 q2 q3 code branch prime_treat main_treat resp_type age1824 male large_city edu_uni B40 pB40 use_energy benefit gov_cap trust right open_resp
saveold "$dataclean\ID_opentext.dta", replace

//pairwise ttest 
use `data1s', clear
keep if main_treat==0
mean cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d [aw=$w]
local xlist cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d
foreach var of local xlist {
	use `data1s', clear
	keep if main_treat==0
	keep code per_quintile act_quintile `var'
	gen gr = "`var'"
	ren `var' value
	append using `datattest'
	save `datattest', replace
}

use `datattest', clear
encode gr, gen(gr2)
table (gr2), statistic(mean value)
table (gr2) (per_quintile), statistic(mean value)
pwmean value, over(gr2) effects
pwmean value if per_quintile==1, over(gr2) effects
pwmean value if per_quintile==2, over(gr2) effects
pwmean value if per_quintile==3, over(gr2) effects
pwmean value if per_quintile==4, over(gr2) effects
pwmean value if per_quintile==5, over(gr2) effects

//Main work
use `data1s', clear

global varlist0 age1824 male large_city edu_uni  
global varlist1 age1824 male large_city edu_uni B40 per_place1 per_place2 use_energy
global varlist1a age1824 male large_city edu_uni B40 per_place1 per_place2 dec_sh_energy
global varlist2 age1824 male large_city edu_uni B40 per_place1 per_place2 use_energy benefit gov_cap trust right 
global varlist2a age1824 male large_city edu_uni B40 per_place1 per_place2 dec_sh_energy benefit gov_cap trust right 

//check distribution between perceived and actual
ta per_quintile act_quintile [aw=$w], col nof

levelsof code, local(codelist)
foreach c of local codelist {
	dis "`c'"
	ta per_quintile act_quintile [aw=$w] if code=="`c'", col nof	
}

*******************************TABLE A2
//Table Characterisics (unweighted) - Table A2
gen gr = "Sample"
append using "${datain}\\Population char data.dta"
gen gr2 = 1 if gr=="Sample"
replace gr2 = 2 if gr=="Pop"
la def gr2 1 "Sample" 2 "Pop"
la val gr2 gr2
la var qt12 "Bottom 40%"
collect: table () (code gr2), statistic(mean male age1824 large_city edu_uni qt12) nototal nformat(%4.2f)
collect style header code gr2, title(hide)
collect preview
collect export "${tables}\\Tables.xlsx", replace sheet(TableA2, replace)
collect export "${tables}\\TableA2.tex", replace 
drop if gr=="Pop"
drop gr gr2
*******************************TABLE A2

*******************************TABLE A1
//Table survey design - all countries combined - Table A1
*recode age1824 (1=1) (0=2), gen(age1824_2)
*la def age1824_2 1 "18-24 years old" 2 "25+ years old"
*la val age1824_2 age1824_2
gen age1824_2 = age1824
la def age1824_2 1 "18-24 years old" 0 "25 years and older"
la val age1824_2 age1824_2

collect: table (branch) (male age1824_2), nototal statistic(percent, across(branch)) nformat(%4.2f)
collect style header male age1824_2 branch, title(hide)
collect preview
collect export "${tables}\\Tables.xlsx", sheet(TableA1, replace) modify
collect export "${tables}\\TableA1.tex", replace 
*******************************TABLE A1

*******************************FIG 2
graph bar (mean) sub_exist benefit right [aw=$w], ///	
	over(code2, label(labsize(small))) ///		
	ytitle(Share of respondents, size(small)) ///
	legend( label(1 "Exist") label(2 "Benefit") label(3 "Right")) ///
	asyvars  intensity(50) legend(rows(1) size(small)) ylabel(0(.2)1, angle(horizontal))
graph export "${figures}\\Figure2.png", wid(3000) replace
*******************************FIG2

*******************************FIG3
graph bar (mean) eff_d  if main_treat==0 [aw=$w], ///	
	over(code2, label(labsize(vsmall))) ///		
	ytitle(Share of respondents, size(small)) ///
	title("Cost more than healthcare") ///
	intensity(50) legend(rows(1) size(small) stack) ylabel(0(.2)1, angle(horizontal)) name(eff_d, replace)

graph bar (mean)  equ_d  if main_treat==0 [aw=$w], ///	
	over(code2, label(labsize(vsmall))) ///		
	ytitle(Share of respondents, size(small)) ///
	title("Mainly benefit richer HHs")  ///
	intensity(50) legend(rows(1) size(small) stack) ylabel(0(.2)1, angle(horizontal)) name(equ_d, replace)
	
graph bar (mean)   env_d if main_treat==0 [aw=$w], ///	
	over(code2, label(labsize(vsmall))) ///		
	ytitle(Share of respondents, size(small)) ///
	title("Damage the environment") fxsize(60) ///
	intensity(50) legend(rows(1) size(small) stack) ylabel(0(.2)1, angle(horizontal)) name(env_d, replace)

graph combine eff_d equ_d , ycommon cols(2) name(first, replace) iscale(1)
graph combine first env_d,  ycommon cols(1) iscale(0.75)
graph export "${figures}\\Figure3.png", wid(3000) replace
*******************************FIG3

*******************************FIG4
graph bar (mean) reduce_d eliminate_d reduce_cost_d    [aw=$w] if main_treat==0, ///	
	legend( label(1 "Reduce") label(2 "Eliminate") label(3 "Reduce with cost")  ) ///	
	over(code2, label(labsize(small))) nofill ///
	ytitle(Share of respondents, size(small)) ///	
	asyvars  intensity(50) legend(rows(1) size(small)) ylabel(0(.2)1, angle(horizontal)) bar(3, color(pink))
graph export "${figures}\\Figure4.png", wid(3000) replace
*******************************FIG4

*******************************FIG5
/*
reghdfe reduce_d male age1824 edu_uni large_city B40 pB40 pmid20 use_energy gov_cap trust right benefit sub_exist [aw=$w], a(code2) vce(cluster code2)
 
est store est_reduce_d
 
reghdfe eliminate_d male age1824 edu_uni large_city B40 pB40 pmid20 use_energy gov_cap trust right benefit sub_exist [aw=$w], a(code2) vce(cluster code2)
 
est store est_eliminate_d
 
reghdfe reduce_cost_d male age1824 edu_uni large_city B40 pB40 pmid20 use_energy gov_cap trust right benefit sub_exist [aw=$w], a(code2) vce(cluster code2)
 
est store est_reduce_cost_d
 
coefplot est_reduce_d, bylabel(Reduce) || ///
		 est_eliminate_d, bylabel(Eliminate) || ///
		 est_reduce_cost_d, bylabel(Reduce with Cost) || ///
		 , norecycle drop(_cons) xline(0) byopts(xrescale legend(off) col(3)) sort(, descending)
 
graph export "$dataout\\Figures\\Fig5.png", replace	
*/
*******************************FIG5

*******************************FIG6	
graph bar (mean) cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d reduce_cost_d  [aw=$w] if main_treat==0, ///	
	legend( label(1 "Cash all HH") label(2 "Cash poor HH") label(3 "Tax cuts") label(4 "Gov spending") ///
	label(5 "Public debt") label(6 "Environment") label(7 "Quality/access") label(8 "W/o another policy") ) ///	
	ytitle(Share of respondents, size(small))  ///		
	asyvars intensity(50) legend(position(6) rows(2) cols(4) size(vsmall) ) ylabel(0(.2)1, angle(horizontal)) 
graph export "${figures}\\Figure6.png", wid(3000) replace
*******************************FIG6	


*******************************DATA FOR FIG7
collect: table () (trust per_place) [aw=$w] if main_treat==0, statistic(mean cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d) nototal nformat(%4.2f)
collect style header trust per_place, title(hide)
collect preview
collect export "${figures}\\Figure7data.xlsx", modify sheet(DataforFig7, replace) 
*******************************DATA FOR FIG7

*******************************FIG8
graph hbar (mean) resp_type3_1 resp_type3_2 resp_type3_3 resp_type3_4   [aw=$w], ///	
	legend( label(1 "Both support") label(2 "Cond. support (spend)") label(3 "Cond. support (other)") label(4 "No support")) ///
	over(code2, label(labsize(small))) ///	
	ytitle(Percentage of respondents, size(small)) ///	
	asyvars  intensity(50) legend(position(6) rows(1) cols(3) size(vsmall) stack) stack
graph export "${figures}\\Figure8.png", wid(3000) replace	 
*******************************FIG8

/*
*******************************FIG8-policy
graph hbar (mean) resp_type3_1 resp_type3_2 resp_type3_3 resp_type3_4   [aw=$w], ///	
	legend( label(1 "Unconditional support") label(2 "Cond. support (spend)") label(3 "Cond. support (other)") label(4 "No support")) ///
	over(code3, label(labsize(small))) ///	
	ytitle(Percentage of respondents, size(small)) ///	
	asyvars  intensity(50) legend(position(6) rows(1) cols(3) size(vsmall) stack) stack
graph export "$dataout\\Figures\\Fig8policy.png", wid(3000) replace	 
graph export "$dataout\\Figures\\Fig8policy.eps",  replace as(eps) 
*******************************FIG8-policy
*/

*******************************FIG A4
graph bar (mean)  cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d reduce_cost_d [aw=$w] if main_treat==0, ///	
	legend( label(1 "Cash all HH") label(2 "Cash poor HH") label(3 "Tax cuts") label(4 "Gov spending") ///
	label(5 "Public debt") label(6 "Environment") label(7 "Quality/access") label(8 "W/o another policy") ) ///	
	over(price_type, label(labsize(small))) nofill ///
	ytitle(Share of respondents, size(small)) ///		
	asyvars  intensity(50) legend(position(6) rows(2) cols(4) size(vsmall)) ylabel(0(.2)1, angle(horizontal)) 
	**bar(1, color(pink))
graph export "${figures}\\FigureA4.png", wid(3000) replace
*******************************FIG A4

*******************************FIG C4
reg sub_exist $varlist1  i.code2 [pw=$w], vce(cluster code2)
est store est_exist

reg benefit $varlist1 i.code2 [pw=$w], vce(cluster code2)
est store benefit

reg right $varlist1 i.code2 [pw=$w], vce(cluster code2)
est store right

coefplot est_exist, bylabel(Exist) || ///
		benefit, bylabel(Benefit) || ///
		right, bylabel(Right) || ///
		, norecycle drop(_cons *.code2) xline(0)  byopts(xrescale legend(off) col(3)) sort(1, descending)
graph export "${figures}\\FigureC4.png", wid(3000) replace
*******************************FIG C4

*******************************FIG C5
reg eff_d $varlist2 i.code2 [pw=$w] if main_treat==0, vce(cluster code2)
est store eff_d
reg equ_d $varlist2 i.code2 [pw=$w] if main_treat==0, vce(cluster code2)
est store equ_d
reg env_d $varlist2 i.code2 [pw=$w] if main_treat==0, vce(cluster code2)
est store env_d

coefplot eff_d, bylabel(Efficiency) || ///
		equ_d, bylabel(Equity) || ///
		env_d, bylabel(Environment) || ///
		,norecycle drop(_cons *.code2) xline(0)  byopts(xrescale legend(off) col(3)) sort(1, descending)
		
graph export "${figures}\\FigureC5.png", wid(3000) replace
*******************************FIG C5

*******************************FIG C6
graph bar (mean) cash_all_d cash_poor_d tax_cuts_d spend_d debt_d environ_d quality_d  [aw=$w] if main_treat==0, ///	
	legend( label(1 "Cash all HH") label(2 "Cash poor HH") label(3 "Tax cuts") label(4 "Gov spending") ///
	label(5 "Public debt") label(6 "Environment") label(7 "Quality/access")) ///
	over(code2, label(labsize(small))) ///	
	ytitle(Share of respondents, size(small)) ///	
	asyvars  intensity(50) legend(position(6) rows(2) cols(4) size(vsmall)) ylabel(0(.2)1, angle(horizontal))
graph export "${figures}\\FigureC6.png", wid(3000) replace
*******************************FIG C6


