//Combine open text data
/*
This dofile: "4 - 1. Cleaning and Appending.do"
Infile: text input data by countries (xlsx and "${dataclean}/ID_opentext.dta")
Outfile: "${datainter}/1. All countries appended.dta"
*/

clear
version 17
set more off

******************************* Append Countries *******************************
*Angola
import excel "${datain}/Angola_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="AGO"
gen country="Angola"

tempfile Angola
save `Angola'

*Argentina
import excel "${datain}/Argentina_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="ARG"
gen country="Argentina"

tempfile Argentina
save `Argentina'

*Bangladesh
import excel "${datain}/Bangladesh_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country="Bangladesh"

tempfile Bangladesh
save `Bangladesh'

*Bolivia
import excel "${datain}/Bolivia_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="BOL"
gen country="Bolivia"

tempfile Bolivia
save `Bolivia'

*Ecuador
import excel "${datain}/Ecuador_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="ECU"
gen country="Ecuador"

tempfile Ecuador
save `Ecuador'

*Egypt
import excel "${datain}/Egypt_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="EGY"
gen country="Egypt"

tempfile Egypt
save `Egypt'

*Ghana:
import excel "${datain}/Open ended Qs.xls", sheet("Sheet1") firstrow clear
keep if country_code=="GHA"

isid Vrid

gen country="Ghana"

tempfile Ghana
save `Ghana'


*Indonesia
import excel "${datain}/Indonesia_eng.xlsx", sheet(" sheet1") firstrow clear
isid Vrid
gen country_code="IDN"
gen country="Indonesia"

tempfile Indonesia
save `Indonesia'

*Kazakhastan
import excel "${datain}/kazakh gsg3 surveys (1).xlsx", sheet(" Sheet1") firstrow clear
tempfile kaz1
save `kaz1'
import excel "${datain}/Russian gsg3 surveys (1).xlsx", sheet(" Sheet1") firstrow clear
append using `kaz1'
drop *language

ren code country_code
replace country_code="KAZ"

gen country="Kazakhastan"

tempfile Kazakhastan
save `Kazakhastan'

*Nigeria:
import excel "${datain}/Open ended Qs.xls", sheet("Sheet1") firstrow clear
keep if country_code=="NGA"

isid Vrid

gen country="Nigeria"

tempfile Nigeria
save `Nigeria'

*Pakistan
import excel "${datain}/Pakistan_eng.xlsx", sheet(" Sheet1") firstrow clear
isid Vrid
gen country_code="PAK"
gen country="Pakistan"

tempfile Pakistan
save `Pakistan'

*Vietnam
import excel "${datain}/Vietnam_eng.xlsx", sheet(" Sheet1") firstrow clear
gen country_code="VNM"
gen country="Vietnam"

tempfile Vietnam
save `Vietnam'

clear
foreach c in Angola Argentina Bangladesh Bolivia Ecuador Egypt Ghana Indonesia Kazakhastan Nigeria Pakistan Vietnam {
	di "`c':"
	append using ``c''
}

************************** Basic cleaning and checks ***************************

	*Some Vrd are text:
	replace Vrid="2345" if Vrid=="2. 3. 4. 5"
	replace Vrid="1996" if Vrid=="nineteen ninety six"
	replace Vrid="345" if Vrid=="3. 4. 5"
	replace Vrid="234" if Vrid=="2. 3. 4"
	replace Vrid="50" if Vrid=="fifty"
	replace Vrid="45" if Vrid=="Four. Five"
	replace Vrid="34" if Vrid=="3. 4"
	replace Vrid="2345" if Vrid=="2. 3. 4. 5"
	replace Vrid="1996" if Vrid=="nineteen ninety six"
	replace Vrid="1995" if Vrid=="nineteen ninety five"
	replace Vrid="345" if Vrid=="3. 4. 5"
	replace Vrid="50" if Vrid=="fifty"
	replace Vrid="45" if Vrid=="Four. Five"
	replace Vrid="34" if Vrid=="3. 4"
	replace Vrid="21" if Vrid=="twenty-one"
	replace Vrid="20" if Vrid=="twenty"
	replace Vrid="2345" if Vrid=="2. 3. 4. 5"
	replace Vrid="1996" if Vrid=="nineteen ninety six"
	replace Vrid="1995" if Vrid=="nineteen ninety five"
	replace Vrid="345" if Vrid=="3. 4. 5"
	replace Vrid="234" if Vrid=="2. 3. 4"
	replace Vrid="50" if Vrid=="fifty"
	replace Vrid="45" if Vrid=="Four. Five"
	replace Vrid="34" if Vrid=="3. 4"
	replace Vrid="21" if Vrid=="twenty-one"
	replace Vrid="20" if Vrid=="twenty"
	replace Vrid="15" if Vrid=="fifteen"
	replace Vrid="11" if Vrid=="eleven"
	replace Vrid="1030" if Vrid=="ten thirty"
	replace Vrid="350" if Vrid=="three hundred fifty"
	replace Vrid="30" if Vrid==" thirty"
	replace Vrid="2013" if Vrid=="two thousand and thirteen"
	replace Vrid="990" if Vrid=="990 yen"
	replace Vrid="94" if Vrid=="ninety four"
	replace Vrid="87" if Vrid=="eighty seven"
	replace Vrid="86" if Vrid=="eighty six"
	replace Vrid="73" if Vrid=="seventy three"
	replace Vrid="67" if Vrid=="sixty seven"
	replace Vrid="64" if Vrid=="sixty four"
	replace Vrid="61" if Vrid=="sixty one"
	replace Vrid="46" if Vrid=="forty six"
	replace Vrid="31" if Vrid=="thirty first"
	replace Vrid="12" if Vrid=="twelfth"
	replace Vrid="10" if Vrid=="ten"

*Unique identifiers
isid country_code Vrid	
destring Vrid, replace
	
*Missing responses
//Both should never be non-missing
tab country_code if q26b_10!="" & q26b_20!=""

//Both can be missing (non-responses)
tab country_code if q26b_10=="" & q26b_20==""

//Q31 can be missing
tab country_code if q31==""

*Mark treatment and control
gen price_treat=10 if q26b_10!=""
replace price_treat=20 if q26b_20!=""

*Combine resposnes:
gen q26b=q26b_10
replace q26b=q26b_20 if q26b==""
drop q26b_*

*Merge in characteristics:
preserve
	use "${dataclean}/ID_opentext.dta", clear

	destring Vrid, replace
	ren code country_code

	isid country_code Vrid
	
	//Both support vs the rest:
	clonevar resp_type_bi = resp_type
	recode resp_type_bi (2=1) (1 3 4 = 2)
	label define resp_type_bi 1 "Only conditional" 2 "The rest", modify
	label values resp_type_bi resp_type_bi
	
	
	//Gov capacity;
	label define gov_cap 1 "High or moderate capacity" 0 "Low or no capacity"
	label values gov_cap gov_cap
	
	//Benefit
	
	//Subsidized user
	label define use_energy 0 "Not subsidized user" 1 "Subsidized user"
	label values use_energy use_energy
	
	//Univeristy
	label define edu_uni 0 "No university" 1 "University educated"
	label values edu_uni edu_uni

	//Open ended response
	label define yesno 0 "No" 1 "Yes"
	label values open_resp yesno

	tempfile chars
	save `chars'
restore
merge 1:1 country_code Vrid using `chars', nogen


*Labels:
label var q26b "Support a reduction in electricity and fuel subsidies if spent on"
label var q31  "Do you feel that this survey was biased?"
label var q1 "Age"
label var age1824 "Age group"
label var q2 "Gender"
label var q3 "Education"
label var branch "Branch"
label var prime_treat "Prime treatment"
label var main_treat "Main treatment"
label var price_treat "Price treatment"
label var trust "Trust in government"
label var resp_type "Respondent type"
label var pB40 "Perceived income" 
label var  B40 "Actual income"
label var use_energy "Subsidized user"
label var gov_cap "Government capacity"
label var open_resp "Didn't answer policy options but answered open text"

*Recast:
format %75s q26b
format %75s q31

*Order and sort:
sort country_code Vrid
order country_code country Vrid q1 q2 q3 q26b q31 branch price_treat prime_treat main_treat resp_type*
compress
saveold "${datainter}/1. All countries appended.dta", replace