//Identify keyworks/themes in the open text data
/*
This dofile: "4 - 2. Identify keywords.do"
Infile: "${datainter}/1. All countries appended.dta"
Outfile: "${datainter}/2. Original responses keywords tagged.dta"
*/

clear
version 17
set more off

/*
global data "$dir/Data"
global raw "$data/Raw Data"
global clean "$data/Output Data"

global output "$dir/Output"
global notes "$dir/Notes"
*/

********************************************************************************
*Programs define
cap program drop keyword
program define keyword
	syntax, question(string) var(string) [strings(string)] [not(string)] [and1(string)] [and2(string)] [exact(string)] [only(string)] [start(string)]  [end(string)]
	
	global strings "`strings'" //list of all keywords
	global not "`not'"
	global and "`and1'"
	global exact "`exact'"
	global only "`only'"
	global start "`start'"
	global end "`end'"
	global and1 "`and1'"	
	global and2 "`and2'"
	
	local var  = subinstr("`var'"," ","_",.)
	
	cap drop kw_`var'
	gen kw_`var'=0 if `question'!=""
	
	//A simple condition for if strings are included
	if !missing(`"`strings'"') {
		foreach string in ${strings} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			replace kw_`var'=1 if strpos(`question',"`string'") 
			replace kw_`var'=1 if `question'=="`string'"
			
		}
	}
	
	//As an exact independant word
	if !missing(`"`exact'"') {		
		foreach string in ${exact} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			
			replace kw_`var'=1 if `question'=="`string'" //exactly that word
			replace kw_`var'=1 if strpos(`question'," `string' ") //with proceeding or preceding space
			replace kw_`var'=1 if strpos(`question',"`string'") ==1 //begining word of string
			replace kw_`var'=1 if strpos(reverse(`question'),reverse("`string'")) ==1 //end word of string
			
		}
	}
	
	//only this word
	if !missing(`"`only'"') {
		foreach string in ${only} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			replace kw_`var'=1 if `question'=="`string'"
			
		}
	}
	
	//Start with this word
	if !missing(`"`start'"') {
		foreach string in ${start} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			replace kw_`var'=1 if strpos(`question',"`string'") ==1
		}
	}
	
	//End with this word
	if !missing(`"`end'"') {
		foreach string in ${end} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			replace kw_`var'=1 if strpos(reverse(`question'),reverse("`string'")) ==1 //end word of string
		}
	}
	
	//Ands (combination of two words)
	if !missing(`"`and2'"') {
		local and1=upper("`and1'") //always look as upper case
		local and2=upper("`and2'") //always look as upper case		
		
		di "`and1'" //this is the first string we look for	
		
		foreach string in ${and2} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the second string we look for
			
			replace kw_`var'=1 if strpos(`question',"`and1'") & strpos(`question',"`string'")	
		}	
		
		*replace kw_`var'=1 if strpos(`question',"`and1'") & strpos(`question',"`and2'") 
	}
	
	//Remove nots (unmarks comments that include this):
	if !missing(`"`not'"') {
		foreach string in ${not} {
			local string=upper("`string'") //always look as upper case
			di "`string'" //this is the final string we look for
			replace kw_`var'=0 if strpos(`question',"`string'") 
			replace kw_`var'=0 if `question'=="`string'"
			
		}
	}
	
	//Labels
	local lab = subinstr("`var'","_"," ",.)
	local lab = proper("`lab'")
	label var kw_`var' "Keyword (`question'): `lab'"
	
	label define yn 0 "No" 1 "Yes", modify
	label values kw_`var' yn
	
	*ren kw_`var' kw_`question'_`var' 
		
end

*Group multiple keywords into a single keyword:
cap program drop combine_kw
program define combine_kw
	syntax, vars(string) name(string) 
	
	ds `vars' 
	//Store in global macro
	global list "`r(varlist)'"

	ereplace `name' = rowmax(`r(varlist)')

	*Drop others:
	local not "`name'"
	local variables "${list}"
	local drop: list variables- not
	drop `drop'
		
	di "${list} "

end

*Group similar keywords into a theme:
cap program drop theme
program define theme
	syntax, vars(string) name(string) [desc(string)] 
	
	cap drop th_`name'
	ds `vars' 
	//Store in global macro
	global `name'_list "`r(varlist)'"
	
	egen th_`name' = rowmax(`r(varlist)')
	
	*Identify question using the kirst keyword
	ds `vars' 
	tokenize "`r(varlist)'"
	di "`1'"
	local question: variable label `1'
	gen temp_lab="`question'"
	split temp_lab, p("(")
	split temp_lab2, p(")")
	
	levelsof temp_lab21
	foreach i in `r(levels)' {
		local question "`i'"
	}
	*local question "`r(levels)'"
	drop temp_lab*

	*Label with description
	if missing(`"`desc'"') {
		local desc = proper("`name'")
	}
	label var th_`name' "Theme (`question'): `desc'"
	
	label values th_`name' yn
	
	*Add theme labels to keywords	
	foreach var in ${`name'_list} {
		local lab: variable label `var'
		label var `var' "`lab'; Theme: `desc'"
	}
	
	di "${`name'_list} "

end

*Save labels:
cap program drop save_labels 
program define save_labels

	qui ds //ind_*
	foreach var in `r(varlist)' {
		cap global lab_`var': variable label `var'
		*di "${lab_`var'}"
	}	
end

*Label indicators
cap program drop label_indicators 
program define label_indicators
	qui ds
	foreach var in 	`r(varlist)' {
		cap label var `var' "${lab_`var'}"		
	}
end

********************************************************************************	
**************************** Keyword identification ****************************
use  "${datainter}/1. All countries appended.dta", clear

foreach q in q26b q31 {
	*Remove special characters to make string identification easier:
	replace `q'=upper(`q')
	foreach i in "." "…" "'" "," "?" "-" ":"  ";" "{" "+"  "=" "}" "%" "-" "/" "*" "@" "#" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" {
		replace `q'=subinstr(`q',"`i'","",.)
	}

	replace `q'=trim(`q')
	replace `q'="" if `q'==" "
	
}
************************************* Q26b *************************************
	
*Remove electricity, gas, fuel if used in repeating the statement:
gen statement_repeated=0
replace statement_repeated=1 if strpos(q26b,"SUPPORT") & (strpos(q26b,"REDUC") | strpos(q26b,"SCRAP"))  & strpos(q26b,"SUBSID")

replace q26b=subinstr(q26b,"ELECTRICITY","",.) if statement_repeated==1
replace q26b=subinstr(q26b,"GAS","",.) 		   if statement_repeated==1
replace q26b=subinstr(q26b,"FUEL","",.)		   if statement_repeated==1
replace q26b=subinstr(q26b,"PETROL","",.) 	   if statement_repeated==1
replace q26b=subinstr(q26b,"MONEY","",.) 	   if statement_repeated==1
replace q26b=subinstr(q26b,"SAVED","",.) 	   if statement_repeated==1


*Code all keywords:
keyword, question("q26b") var("parks") strings(`"parks"')
keyword, question("q26b") var("community") strings(`"commun "')
keyword, question("q26b") var("recreation") strings(`"recreation"')
keyword, question("q26b") var("kwanza") strings(`"kwanza"')
keyword, question("q26b") var("religion") strings(`"religion"')
keyword, question("q26b") var("islam") strings(`"islam"')
keyword, question("q26b") var("football") strings(`"football"')
keyword, question("q26b") var("entertain") strings(`"entertain"')
keyword, question("q26b") var("sports") strings(`"`"sport"'"') not(`" `"transport"' "')
keyword, question("q26b") var("social utilities") and1(`"social"') and2(`"`"improv"'  `"problem"'  `"sphere"'"')
keyword, question("q26b") var("social amenities") strings(`"`"amenit"'  `"aminities"' "')
keyword, question("q26b") var("public_good") and1("public") and2("good")
keyword, question("q26b") var("public areas") and1(`"public"') and2(`"`"area"' `"facil"'  "')
keyword, question("q26b") var("city") strings(`"`"city"'  `"cities"'"') not(`" `"electr"'  `"elet"'  `"capacity"' "')
keyword, question("q26b") var("places") strings(`"places"')
keyword, question("q26b") var("games") strings(`"game"')
keyword, question("q26b") var("cultural") strings(`"cultur"') not(`" `"agri"' "')
keyword, question("q26b") var("centers") strings(`"centers"')
keyword, question("q26b") var("families") strings(`"famil"') not(`" `"basket"' `"poor"'  "')
keyword, question("q26b") var("society") strings(`"society"')
keyword, question("q26b") var("neighborhood") strings(`"neighborhood"')
keyword, question("q26b") var("decoration") strings(`"decoration"')
keyword, question("q26b") var("art") exact(`"art"')
keyword, question("q26b") var("fauna") strings(`"fauna"')
keyword, question("q26b") var("cat") exact(`"cat"')
keyword, question("q26b") var("dog") exact(`"dog"')
keyword, question("q26b") var("stray") strings(`"stray"')
keyword, question("q26b") var("nurseries") strings(`"nurser"')
keyword, question("q26b") var("mosque") strings(`"mosque"')
keyword, question("q26b") var("minorities") strings(`"minorit"')
keyword, question("q26b") var("church") strings(`"church"')
keyword, question("q26b") var("landscaping") strings(`"landscap"')
keyword, question("q26b") var("animal shelter") strings(`"animal shelter"')
keyword, question("q26b") var("playground") strings(`"playground"')
keyword, question("q26b") var("disaster") strings(`"disaster"')
keyword, question("q26b") var("humanity") strings(`"humanity"')
keyword, question("q26b") var("mankind") strings(`"mankind"')
keyword, question("q26b") var("drought") strings(`"drought"')
keyword, question("q26b") var("flood") strings(`"flood"')
keyword, question("q26b") var("earthquake") strings(`"earthquake"')
keyword, question("q26b") var("refugee") strings(`"refugee"')
keyword, question("q26b") var("displaced") strings(`"displaced"')
keyword, question("q26b") var("rohingya") strings(`"rohingya"')
keyword, question("q26b") var("idp") strings(`"idp"')
keyword, question("q26b") var("visa") strings(`"visa"')
keyword, question("q26b") var("development") only(`"`"develop"' `"development"' `"development work"' `"for development"' `"better development"'"')
keyword, question("q26b") var("economic development") and1(`"econ"') and2(`"devel"')
combine_kw, vars(kw_development-kw_economic_development) name(kw_economic_development)
keyword, question("q26b") var("overall development") and1(`"develop"') and2(`"`"country"' `"nation"' `"overall"' `"people"' `"public"' "')
keyword, question("q26b") var("sustainable development") exact(`"`"sustainable development"'"')
keyword, question("q26b") var("welfare") strings(`"welfare"')
keyword, question("q26b") var("prosperity") strings(`"prosper"')
keyword, question("q26b") var("living conditions") and1(`"liv"') and2(`"condition"')
keyword, question("q26b") var("standard of living") and1(`"stand"') and2(`"liv"')
keyword, question("q26b") var("socioeconomic development") and1(`"soci"') and2(`"econ"')
keyword, question("q26b") var("institutions") strings(`"institut"')
keyword, question("q26b") var("development projects") start(`"project*"')
keyword, question("q26b") var("capital project") and1(`"project"') and2(`"capital"')
keyword, question("q26b") var("ventures") strings(`"venture"')
keyword, question("q26b") var("new program") and1(`"program"') and2(`"new"')
keyword, question("q26b") var("useful program") and1(`"program"') and2(`"useful"')
keyword, question("q26b") var("increase_projects") and1(`"project"') and2(`"increase"')
keyword, question("q26b") var("abandoned project") and1(`"project"') and2(`"abandon"')
combine_kw, vars(kw_development_projects-kw_abandoned_project) name(kw_development_projects)
keyword, question("q26b") var("productivity") strings(`"producti"')
keyword, question("q26b") var("progress") strings(`"progress"')
keyword, question("q26b") var("better_life") and1(`"better"') and2(`"`"life"'  `"live"'  `"living"'  `"future"' "')
keyword, question("q26b") var("life") start(`"life"')
keyword, question("q26b") var("the economy") strings(`"econ"') not(`" `"second"'  `"grow"' "')
keyword, question("q26b") var("basic needs") and1(`"basic"') and2(`"need"')
keyword, question("q26b") var("economic growth") and1(`"grow"') and2(`"`"econ"'  `"country"' "')
keyword, question("q26b") var("per capita income") and1(`"per"') and2(`"capita"')
keyword, question("q26b") var("qualify of life") and1(`"qual"') and2(`"life"')
keyword, question("q26b") var("improving life") and1(`"improv"') and2(`"`"life"' `"lives"'"')
keyword, question("q26b") var("remote areas") strings(`"remote"')
keyword, question("q26b") var("education") strings(`"`"educa"'`"eduaction"' `"eucation"' "')
keyword, question("q26b") var("university") strings(`"universi"')
keyword, question("q26b") var("school") strings(`"school"')
keyword, question("q26b") var("college") strings(`"college"')
keyword, question("q26b") var("tuition") strings(`"tuition"')
keyword, question("q26b") var("learn") strings(`"learn"')
keyword, question("q26b") var("student") strings(`"stud"')
keyword, question("q26b") var("pupil") strings(`"pupil"')
keyword, question("q26b") var("teach") strings(`"teach"')
keyword, question("q26b") var("scholarship") strings(`"scholar"')
keyword, question("q26b") var("research") strings(`"research"')
keyword, question("q26b") var("qualification") strings(`"qualif"')
keyword, question("q26b") var("library") strings(`"librar"')
keyword, question("q26b") var("literacy") strings(`"literacy"')
keyword, question("q26b") var("elderly") strings(`"elderly"')
keyword, question("q26b") var("nursing_home") and1(`"nursing"') and2(`"home"')
keyword, question("q26b") var("old_home") and1(`"old"') and2(`"home"')
keyword, question("q26b") var("child_care") and1(`"child"') and2(`"care"')
keyword, question("q26b") var("orphan") strings(`"orphan"')
keyword, question("q26b") var("children") strings(`"child"')
keyword, question("q26b") var("kids") strings(`"kids"')
keyword, question("q26b") var("older") strings(`"older"')
keyword, question("q26b") var("single_mother") and1(`"single"') and2(`"mother"')
keyword, question("q26b") var("special_need") and1(`"special"') and2(`"need"')
keyword, question("q26b") var("asylum") strings(`"asylum"')
keyword, question("q26b") var("kindergarten") strings(`"kindergarten"')
keyword, question("q26b") var("job") strings(`"job"')
keyword, question("q26b") var("employment") strings(`"employ"')
keyword, question("q26b") var("opportunities") strings(`"opportu"')
keyword, question("q26b") var("entrepreneurship") strings(`"entrep"')
keyword, question("q26b") var("skills") strings(`"skill"')
keyword, question("q26b") var("training") strings(`"training"')
keyword, question("q26b") var("salary") strings(`"salar"')
keyword, question("q26b") var("improv_livelihood") and1(`"improv"') and2(`"livel"')
keyword, question("q26b") var("labor force") strings(`"`"labor"' `"labour"'"')
keyword, question("q26b") var("human_development") and1(`"human"') and2(`"develop"')
keyword, question("q26b") var("human_capital") and1(`"human"') and2(`"capital"')
keyword, question("q26b") var("increase income") start(`"income"')
keyword, question("q26b") var("income sources") and1(`"income"') and2(`"`"source"' `"month"'"')
keyword, question("q26b") var("access to funding") and1(`"fund"') and2(`"acce"')
keyword, question("q26b") var("small_business") and1(`"small"') and2(`"business"')
keyword, question("q26b") var("young_people") and1(`"young"') and2(`"people"')
keyword, question("q26b") var("youth") strings(`"youth"')
keyword, question("q26b") var("work") strings(`"work"') not(`" `"public work"' "')
keyword, question("q26b") var("wage") strings(`"wage"')
keyword, question("q26b") var("unemployment") strings(`"unemploy"')
keyword, question("q26b") var("micro_business") and1(`"micro"') and2(`"business"')
keyword, question("q26b") var("loan") strings(`"loan"')
keyword, question("q26b") var("credit") strings(`"credit"')
keyword, question("q26b") var("micro finance") strings(`"micro finance"')
keyword, question("q26b") var("human_resource") and1(`"human"') and2(`"resource"')
keyword, question("q26b") var("sme") strings(`"sme"')
keyword, question("q26b") var("freelance") strings(`"freelance"')
keyword, question("q26b") var("start_up") and1(`"start"') and2(`"up"')
keyword, question("q26b") var("pay_rise") and1(`"pay"') and2(`"rise"')
keyword, question("q26b") var("interest_free") and1(`"interest"') and2(`"free"')
keyword, question("q26b") var("career") strings(`"career"')
keyword, question("q26b") var("environment") strings(`"enviro"')
keyword, question("q26b") var("reclaim") strings(`"reclaim"')
keyword, question("q26b") var("pollution") strings(`"pollut"')
keyword, question("q26b") var("air") exact(`"air"')
keyword, question("q26b") var("clean") strings(`"clean"')
keyword, question("q26b") var("noise") strings(`"noise"')
keyword, question("q26b") var("ecological") strings(`"ecolog"')
keyword, question("q26b") var("nature") strings(`"natur"')
keyword, question("q26b") var("land reclamation") and1(`"land"') and2(`"reclam"')
keyword, question("q26b") var("earth") strings(`"earth"')
keyword, question("q26b") var("reducing emissions") strings(`"emiss"')
keyword, question("q26b") var("global warming") and1(`"glob"') and2(`"warm"')
keyword, question("q26b") var("plastic_waste") and1(`"plastic"') and2(`"waste"')
keyword, question("q26b") var("tree") strings(`"tree"')
keyword, question("q26b") var("sustainable") strings(`"sustain"') not(`" `"develop"' "')
keyword, question("q26b") var("forest") strings(`"forest"')
keyword, question("q26b") var("river") strings(`"river"')
keyword, question("q26b") var("climate") strings(`"climate"')
keyword, question("q26b") var("food") strings(`"food"')
keyword, question("q26b") var("agriculture") strings(`"agri"')
keyword, question("q26b") var("drink") strings(`"drink"') not(`" `"water"' "')
keyword, question("q26b") var("nutrition") strings(`"nutrition"')
keyword, question("q26b") var("sugar") strings(`"sugar"')
keyword, question("q26b") var("rice") strings(`"rice"') not(`" `"price"' "')
keyword, question("q26b") var("cooking oil") strings(`"cooking oil"')
keyword, question("q26b") var("wheat") strings(`"wheat"')
keyword, question("q26b") var("cotton") strings(`"cotton"')
keyword, question("q26b") var("farm") strings(`"farm"')
keyword, question("q26b") var("canal") strings(`"canal"')
keyword, question("q26b") var("irrigation") strings(`"irrigat"')
keyword, question("q26b") var("grocery") strings(`"grocer"')
keyword, question("q26b") var("plantation") strings(`"plantation"')
keyword, question("q26b") var("kitchens") strings(`"kitchen"')
keyword, question("q26b") var("cook") strings(`"cook"')
keyword, question("q26b") var("bread") strings(`"bread"')
keyword, question("q26b") var("diet") strings(`"diet"')
keyword, question("q26b") var("cocoa") strings(`"cocoa"')
keyword, question("q26b") var("feed") strings(`"feed"')
keyword, question("q26b") var("rural") strings(`"rural"')
keyword, question("q26b") var("soil") strings(`"soil"')
keyword, question("q26b") var("tractor") strings(`"tractor"')
keyword, question("q26b") var("tubewell") strings(`"tubewell"')
keyword, question("q26b") var("cultivation") strings(`"cultivation"')
keyword, question("q26b") var("fish") strings(`"fish"')
keyword, question("q26b") var("livestock") strings(`"livestock"')
keyword, question("q26b") var("hunger") strings(`"hunger"')
keyword, question("q26b") var("meal") strings(`"meal"')
keyword, question("q26b") var("village") strings(`"village"')
keyword, question("q26b") var("fruits") strings(`"fruits"')
keyword, question("q26b") var("governance") strings(`"governance"')
keyword, question("q26b") var("government") start(`"`"government"'"')
keyword, question("q26b") var("corruption") strings(`"corrupt"')
keyword, question("q26b") var("pocket") strings(`"pocket"')
keyword, question("q26b") var("regulation") strings(`"regulat"')
keyword, question("q26b") var("reform") strings(`"reform"')
keyword, question("q26b") var("better public management") and1(`"public"') and2(`"manag"')
keyword, question("q26b") var("better money management") and1(`"money"') and2(`"manag"')
keyword, question("q26b") var("proper use of money") and1(`"money"') and2(`"proper"')
keyword, question("q26b") var("politician") strings(`"politic"')
keyword, question("q26b") var("bureaucracy") strings(`"burea"')
keyword, question("q26b") var("foreign_relation") and1(`"foreign"') and2(`"relation"')
keyword, question("q26b") var("debt") strings(`""debt" "debit"  "dept""')
keyword, question("q26b") var("reduce public spending") and1(`"publ"') and2(`"spend"')
keyword, question("q26b") var("reduce public burden") and1(`"publ"') and2(`"burden"')
keyword, question("q26b") var("justice") strings(`"justice"')
keyword, question("q26b") var("assembly") strings(`"assembl"')
keyword, question("q26b") var("fraud") strings(`"fraud"')
keyword, question("q26b") var("loot") strings(`"loot"')
keyword, question("q26b") var("steal") strings(`"steal"')
keyword, question("q26b") var("crook") strings(`"crook"')
keyword, question("q26b") var("thieves") strings(`"thie"')
keyword, question("q26b") var("world_bank") and1(`"world"') and2(`"bank"')
keyword, question("q26b") var("monetary_fund") and1(`"monetary"') and2(`"fund"')
keyword, question("q26b") var("imf") strings(`"imf"')
keyword, question("q26b") var("courts") strings(`"court"')
keyword, question("q26b") var("legislation") strings(`"legisl"')
keyword, question("q26b") var("better policy ") start(`"policy"')
keyword, question("q26b") var("government officials") strings(`"`"official"' `"officer"' "')
keyword, question("q26b") var("reduce expenditure") and1(`"reduc"') and2(`"`"expen"' `"spend"'"')
keyword, question("q26b") var("improved administration") strings(`"adminis"')
keyword, question("q26b") var("election") strings(`"election"') not(`" `"selection"' "')
keyword, question("q26b") var("human rights") strings(`"`"human right"'"')
keyword, question("q26b") var("plunder") strings(`"plunder"')
keyword, question("q26b") var("transparency") strings(`"transparen"')
keyword, question("q26b") var("health") strings(`"`"health"'`"heath"'  "')
keyword, question("q26b") var("hospital") strings(`"hospital"')
keyword, question("q26b") var("doctor") strings(`"doctor"')
keyword, question("q26b") var("primary care") and1(`"primar"') and2(`"care"')
keyword, question("q26b") var("dental") strings(`"dental"')
keyword, question("q26b") var("surgery") strings(`"surgery"')
keyword, question("q26b") var("nurse") strings(`"nurse"')
keyword, question("q26b") var("clinic") strings(`"clinic"')
keyword, question("q26b") var("disease") strings(`"disease"')
keyword, question("q26b") var("medicine") strings(`"medic"')
keyword, question("q26b") var("malaria") strings(`"malaria"')
keyword, question("q26b") var("hiv") strings(`"hiv"')
keyword, question("q26b") var("aids") strings(`"aids"')
keyword, question("q26b") var("stunting") strings(`"stunting"')
keyword, question("q26b") var("cancer") strings(`"cancer"')
keyword, question("q26b") var("treatment") strings(`"treatment"')
keyword, question("q26b") var("sick") strings(`"sick"')
keyword, question("q26b") var("maternity") strings(`"matern"')
keyword, question("q26b") var("housing") strings(`"hous"') not(`" "household" "')
keyword, question("q26b") var("home") strings(`"home"') not(`" "homeless" "')
keyword, question("q26b") var("shelter") strings(`"shelter"')
keyword, question("q26b") var("house construction") and1(`"construct"') and2(`"house"')
keyword, question("q26b") var("residences") strings(`"residen"')
keyword, question("q26b") var("homeless") strings(`"homeless"')
keyword, question("q26b") var("real estate") strings(`"`"real estate"'"')
keyword, question("q26b") var("apartment") strings(`"apartment"')
keyword, question("q26b") var("electrical system") and1(`"system"') and2(`"`"electr"' `"power"' "')
keyword, question("q26b") var("transmission") strings(`"transm"')
keyword, question("q26b") var("build power plants") and1(`"power"') and2(`"plant"')
keyword, question("q26b") var("load shedding") and1(`"load"') and2(`"shed"')
keyword, question("q26b") var("overload") and1(`"load"') and2(`"over"')
keyword, question("q26b") var("reduce power consumption") and1(`"power"') and2(`"cons"')
keyword, question("q26b") var("power_supply") and1(`"power"') and2(`"supply"')
keyword, question("q26b") var("power outage") and1(`"power"') and2(`"`"cut"' `"out"'"')
keyword, question("q26b") var("power generation") and1(`"power"') and2(`"gener"')
keyword, question("q26b") var("inflation") strings(`"inflation"')
keyword, question("q26b") var("cost of living") strings(`"cost"') not(`" `"electr"'  `"fuel"'  `"gas"'  "')
keyword, question("q26b") var("low_price") and1(`"low"') and2(`"price"') not(`" `"fuel"' `"electricity"' `"gas"' `"petrol"' "')
keyword, question("q26b") var("pricing") strings(`"pricing"')
keyword, question("q26b") var("charges on goods ") and1(`"charge"') and2(`"good"')
keyword, question("q26b") var("custom duties") and1(`"custom"') and2(`"`"dut"' `"foreign"'"')
keyword, question("q26b") var("ends_meet") and1(`"ends"') and2(`"meet"')
keyword, question("q26b") var("affordability") strings(`"afford"')
keyword, question("q26b") var("consumer") strings(`"consumer"')
keyword, question("q26b") var("hike") strings(`"hike"')
keyword, question("q26b") var("rent") strings(`"rent"') not(`" `"different"' `"current"' `"parent"' "')
keyword, question("q26b") var("tarif") strings(`"`"tarrif'"' `"tarif"' `"tarriff"' `"terrif"' "')
keyword, question("q26b") var("cheap") strings(`"cheap"')
keyword, question("q26b") var("basic basket") and1(`"basic"') and2(`"basket"')
keyword, question("q26b") var("family basket") and1(`"famil"') and2(`"basket"')
keyword, question("q26b") var("dollar") strings(`"dollar"')
keyword, question("q26b") var("budget") start(`"budget"')
keyword, question("q26b") var("currency") strings(`"currency"')
keyword, question("q26b") var("exchange rate") and1(`"exch"') and2(`"rate"')
keyword, question("q26b") var("groceries") strings(`"grocer"')
keyword, question("q26b") var("rupee") strings(`"rupee"')
keyword, question("q26b") var("naira") strings(`"naira"')
keyword, question("q26b") var("takka") strings(`"`"taka"' `"takka"' "')
keyword, question("q26b") var("devaluation") strings(`"devalu"')
keyword, question("q26b") var("mineral") strings(`"mineral"')
keyword, question("q26b") var("natural resource") and1(`"natur"') and2(`"resou"')
keyword, question("q26b") var("resources") start(`"resource"')
keyword, question("q26b") var("exploration") strings(`"explorat"')
keyword, question("q26b") var("coal") strings(`"coal"')
keyword, question("q26b") var("diamond") strings(`"diamond"')
keyword, question("q26b") var("mining") strings(`"mining"')
keyword, question("q26b") var("gold") strings(`"gold"')
keyword, question("q26b") var("asphalt") strings(`"asphalt"')
keyword, question("q26b") var("lithium") strings(`"lithium"')
keyword, question("q26b") var("iron") strings(`"iron"') not(`" `"environ"' "')
keyword, question("q26b") var("the people") start(`"`"the people"' `"people"' `"the public"' `"public"' `"awam"' `"awaam"' `"persons"' `"individuals"'"')
keyword, question("q26b") var("to the people") and1(`"to"') and2(`"`"the people"'"')
keyword, question("q26b") var("for the people") and1(`"for"') and2(`"`"the people"'"')
keyword, question("q26b") var("all the people") and1(`"all"') and2(`"`"the people"'"')
keyword, question("q26b") var("in the people") and1(`"in"') and2(`"`"the people"'"')
keyword, question("q26b") var("spend on people") and1(`"spen"') and2(`"`"people"'"')
keyword, question("q26b") var("for people") strings(`"`"for people"'"')
keyword, question("q26b") var("on the people") and1(`"on"') and2(`"`"the people"'"')
keyword, question("q26b") var("of people") strings(`"`"of people"' `"of the people"'"')
keyword, question("q26b") var("our people") strings(`"`"our people"'"')
keyword, question("q26b") var("needs of the people") and1(`"people"') and2(`"need"')
keyword, question("q26b") var("helping people") and1(`"people"') and2(`"help"')
keyword, question("q26b") var("investing in people") and1(`"people"') and2(`"invest"')
keyword, question("q26b") var("all of the people") and1(`"people"') and2(`"fect"')
keyword, question("q26b") var("benefit people") and1(`"people"') and2(`"benef"')
keyword, question("q26b") var("the right people") and1(`"people"') and2(`"right"')
keyword, question("q26b") var("affected people") and1(`"people"') and2(`"all"')
keyword, question("q26b") var("wellbeing of the people") and1(`"people"') and2(`"wellb"')
keyword, question("q26b") var("interests of the people") and1(`"people"') and2(`"interest"')
keyword, question("q26b") var("on the right people") strings(`"`"right people"'"')
keyword, question("q26b") var("general people") strings(`"`"general people"'"')
keyword, question("q26b") var("common people") strings(`"`"common people"'"')
keyword, question("q26b") var("supporting the people") and1(`"people"') and2(`"support"')
keyword, question("q26b") var("whole of the people") and1(`"people"') and2(`"whole"')
keyword, question("q26b") var("people in the country") and1(`"people"') and2(`"`"in country"'"')
keyword, question("q26b") var("lives of the people") and1(`"people"') and2(`"live"')
keyword, question("q26b") var("people problems") and1(`"people"') and2(`"problems"')
keyword, question("q26b") var("condition of the people") and1(`"people"') and2(`"condition"')
keyword, question("q26b") var("for the public") and1(`"for"') and2(`"public"')
keyword, question("q26b") var("myself") start(`"`"myself"'"')
keyword, question("q26b") var("on all") only(`"`"all"' `"on all"'"')
keyword, question("q26b") var("on me") only(`"`"me"' `"on me"'"')
keyword, question("q26b") var("majority") start(`"`"majority"'"')
keyword, question("q26b") var("persons") start(`"`"person"'"')
keyword, question("q26b") var("public issues") and1(`"issue"') and2(`"public"')
keyword, question("q26b") var("users") start(`"`"the users"' `"users"' "')
combine_kw, vars(kw_the_people-kw_users) name(kw_for_the_people)
keyword, question("q26b") var("human beings") strings(`"`"human"' `"human being"' "') not(`" `"resource"' `"humanit"' "')
keyword, question("q26b") var("masses") exact(`"masses"')
keyword, question("q26b") var("population") strings(`"population"')
keyword, question("q26b") var("citizens") strings(`"citizen"')
keyword, question("q26b") var("country") start(`"`"the country"' `"country"'"')
keyword, question("q26b") var("nation") exact(`"nation"')
keyword, question("q26b") var("progress of the nation") and1(`"progress"') and2(`"nation"')
keyword, question("q26b") var("improve the country") and1(`"improve"') and2(`" country"')
keyword, question("q26b") var("for the country") and1(`"for"') and2(`"`"the country"'"')
keyword, question("q26b") var("on the country") and1(`"on"') and2(`"`"the country"'"')
keyword, question("q26b") var("in the country") and1(`"in"') and2(`"`"the country"'"')
keyword, question("q26b") var("good of the country") and1(`"country"') and2(`"`"good of"'"')
keyword, question("q26b") var("my country") start(`"`"my country"' "')
keyword, question("q26b") var("betterment of the country") and1(`"better"') and2(`"country"')
keyword, question("q26b") var("improve the country") and1(`"impro"') and2(`"country"')
keyword, question("q26b") var("greaty country") and1(`"great"') and2(`"country"')

combine_kw, vars(kw_country-kw_greaty_country) name(kw_on_the_country)
keyword, question("q26b") var("poverty") strings(`"poverty"')
keyword, question("q26b") var("alleviate") strings(`"alleviate"')
keyword, question("q26b") var("helping the poor") strings(`"`"poor"' `"destitute"' `"in need"' `"needy"' `"disadvantaged"' `"ghareeb"' `"ghreeb"' `"gareeb"' `"beggar"' `"low class"' "')
keyword, question("q26b") var("those in need") strings(`"`"in need"' `"needy"' "')
keyword, question("q26b") var("vulnerable people") strings(`"`"vulnerable"' "')
keyword, question("q26b") var("help those with nothing") and1(`"those"') and2(`"nothing"')
keyword, question("q26b") var("those who really need it") and1(`"those"') and2(`"need"')
combine_kw, vars(kw_help_those_with_nothing-kw_those_who_really_need_it) name(kw_those_who_really_need_it)
keyword, question("q26b") var("less privilege") and1(`"priv"') and2(`"`"under"' `"less"'"')
keyword, question("q26b") var("middle class") strings(`"`"middle class"'"')
keyword, question("q26b") var("redistribution") strings(`"redistribut"')
keyword, question("q26b") var("donation") strings(`"donat"')
keyword, question("q26b") var("equitable") strings(`"equitable"')
keyword, question("q26b") var("charity") strings(`"charit"')
keyword, question("q26b") var("low_income") and1(`"low"') and2(`"income"')
keyword, question("q26b") var("suffering") strings(`"suffering"')
keyword, question("q26b") var("safety") strings(`"safety"')
keyword, question("q26b") var("police") strings(`"police"')
keyword, question("q26b") var("military") strings(`"military"')
keyword, question("q26b") var("army") strings(`"army"')
keyword, question("q26b") var("armed_force") and1(`"armed"') and2(`"force"')
keyword, question("q26b") var("cameras") strings(`"cameras"')
keyword, question("q26b") var("security") strings(`"secur"') not(`" "food" "social" "')
keyword, question("q26b") var("crime") strings(`"crime"')
keyword, question("q26b") var("safe travel") and1(`"safe"') and2(`"travel"')
keyword, question("q26b") var("border") strings(`"border"')
keyword, question("q26b") var("penitentiary") strings(`"penitentiary"')
keyword, question("q26b") var("jail") strings(`"jail"')
keyword, question("q26b") var("prison") strings(`"prison"')
keyword, question("q26b") var("criminal") strings(`"criminal"')
keyword, question("q26b") var("peace") strings(`"peace"')
keyword, question("q26b") var("drugs") strings(`"drugs"')
keyword, question("q26b") var("property") strings(`"`"property"'"')
keyword, question("q26b") var("defense") strings(`"`"defense"' `"defence"' "')
keyword, question("q26b") var("violence") strings(`"violence"')
keyword, question("q26b") var("law_order") and1(`"law"') and2(`"order"')
keyword, question("q26b") var("renewable") strings(`"renewable"')
keyword, question("q26b") var("solar") strings(`"solar"')
keyword, question("q26b") var("wind") strings(`"wind"')
keyword, question("q26b") var("hydro") strings(`"hydro"')
keyword, question("q26b") var("dams") strings(`"dams"')
keyword, question("q26b") var("dam") exact(`"dam"')
keyword, question("q26b") var("clean energy") strings(`"`"clean energy"'"')
keyword, question("q26b") var("green energy") strings(`"`"green energy"'"')
keyword, question("q26b") var("reservoir") strings(`"reservoir"')
keyword, question("q26b") var("battery") strings(`"batter"')
keyword, question("q26b") var("biofuel") strings(`"`"bio diesel"' `"bio fuel"' `"biodiesel"' `"biofuel"' "')
keyword, question("q26b") var("alternate power") and1(`"alter"') and2(`"power"')
keyword, question("q26b") var("nuclear_power") and1(`"nuclear"') and2(`"power"')
keyword, question("q26b") var("energy_saving") and1(`"energy"') and2(`"saving"')
keyword, question("q26b") var("cash") strings(`"cash"')
keyword, question("q26b") var("grant") strings(`"grant"')
keyword, question("q26b") var("pension") strings(`"pension"')
keyword, question("q26b") var("retire") strings(`"retire"')
keyword, question("q26b") var("reduce social plans") and1(`"social"') and2(`"plan"')
keyword, question("q26b") var("money") start(`"`"money"' "')
keyword, question("q26b") var("payouts") strings(`"`"payout"' "')
keyword, question("q26b") var("monthly payment") and1(`"month"') and2(`"`"paym"' `"stipend"'  "')
keyword, question("q26b") var("savings") strings(`"`"saving"' "')
keyword, question("q26b") var("save") start(`"save"')
keyword, question("q26b") var("households") start(`"`"household"' `"the household"'"')
keyword, question("q26b") var("helping households") and1(`"help"') and2(`"household"')
keyword, question("q26b") var("funding households") and1(`"fund"') and2(`"household"')
keyword, question("q26b") var("household needs") and1(`"needs"') and2(`"household"')
combine_kw, vars(kw_households-kw_household_needs) name(kw_helping_households)
keyword, question("q26b") var("right things") and1(`"neces"') and2(`"things"')
keyword, question("q26b") var("general needs") and1(`"general"') and2(`"needs"')
keyword, question("q26b") var("daily needs") and1(`"daily"') and2(`"needs"')
keyword, question("q26b") var("everyday live") and1(`"every"') and2(`"live"')
keyword, question("q26b") var("everyday life") and1(`"every"') and2(`"life"')
keyword, question("q26b") var("essential needs") and1(`"essential"') and2(`"need"')
keyword, question("q26b") var("daily necessities") and1(`"neces"') and2(`"life"')
keyword, question("q26b") var("necessary things") and1(`"neces"') and2(`"things"')
keyword, question("q26b") var("personal needs") and1(`"person"') and2(`"need"')
keyword, question("q26b") var("make ends meet") and1(`"end"') and2(`"meet"')
keyword, question("q26b") var("individual needs") and1(`"individual"') and2(`"needs"')
combine_kw, vars(kw_right_things-kw_individual_needs) name(kw_daily_necessities)
keyword, question("q26b") var("assistance") strings(`"assistance"')
keyword, question("q26b") var("disabled") strings(`"disab"')
keyword, question("q26b") var("transfers") strings(`"transfers"')
keyword, question("q26b") var("social_security") and1(`"social"') and2(`"security"')
keyword, question("q26b") var("tax") strings(`"tax"') not(`" "taxi" "')
keyword, question("q26b") var("fiscal") strings(`"fiscal"')
keyword, question("q26b") var("vat") exact(`"vat"')
keyword, question("q26b") var("gst") strings(`"gst"')
keyword, question("q26b") var("technology") strings(`"tech"')
keyword, question("q26b") var("innovation") strings(`"innov"')
keyword, question("q26b") var("science") strings(`"scien"')
keyword, question("q26b") var("modernize") strings(`"moderni"')
keyword, question("q26b") var("advancement") strings(`"`"advanced"' `"advances"' `"advancement"' "')
keyword, question("q26b") var("internet") strings(`"internet"')
keyword, question("q26b") var("electronics") strings(`"electron"')
keyword, question("q26b") var("bitcoin") strings(`"bitcoin"')
keyword, question("q26b") var("crypto") strings(`"crypto"')
keyword, question("q26b") var("smartphone") strings(`"smartphone"')
keyword, question("q26b") var("mobile_phone") and1(`"mobile"') and2(`"phone"')
keyword, question("q26b") var("laptop") strings(`"laptop"')
keyword, question("q26b") var("computer") strings(`"comput"')
keyword, question("q26b") var("ai") only(`"ai"')
keyword, question("q26b") var("artificial intelligence") and1(`"arti"') and2(`"intel"')
combine_kw, vars(kw_ai-kw_artificial_intelligence) name(kw_artificial_intelligence)
keyword, question("q26b") var("it") only(`"it"')
keyword, question("q26b") var("it sector") and1(`"it"') and2(`"sect"')
keyword, question("q26b") var("ict") exact(`"ict"')
combine_kw, vars(kw_it-kw_ict) name(kw_it_sector)
keyword, question("q26b") var("digital") strings(`"digital"')
keyword, question("q26b") var("trade") strings(`"trade"')
keyword, question("q26b") var("industry") strings(`"industr"')
keyword, question("q26b") var("factory") strings(`"factor"')
keyword, question("q26b") var("business") strings(`"business"')
keyword, question("q26b") var("manufacturing") strings(`"manufac"')
keyword, question("q26b") var("investment") strings(`"investment"')
keyword, question("q26b") var("bank") strings(`"bank"')
keyword, question("q26b") var("insurance") strings(`"insur"')
keyword, question("q26b") var("import") strings(`"import"')
keyword, question("q26b") var("export") strings(`"export"')
keyword, question("q26b") var("tourism") strings(`"touris"')
keyword, question("q26b") var("financing") strings(`"financing"')
keyword, question("q26b") var("production") strings(`"production"')
keyword, question("q26b") var("companies") strings(`"compan"')
keyword, question("q26b") var("public works") and1(`"public"') and2(`"work"')
keyword, question("q26b") var("interest rate") and1(`"inter"') and2(`"rate"')
keyword, question("q26b") var("usury") strings(`"usury"')
keyword, question("q26b") var("financial average rate") and1(`"financial"') and2(`"aver"')
keyword, question("q26b") var("raw material") strings(`"raw material"')
keyword, question("q26b") var("refinery") strings(`"refin"')
keyword, question("q26b") var("steel") strings(`"steel"')
keyword, question("q26b") var("transport") strings(`"transport"')
keyword, question("q26b") var("infrastructure") strings(`"infrastructure"')
keyword, question("q26b") var("road") strings(`"road"')
keyword, question("q26b") var("highway") strings(`"highway"')
keyword, question("q26b") var("buses") strings(`"buses"')
keyword, question("q26b") var("rail") strings(`"rail"')
keyword, question("q26b") var("train") strings(`"train"')
keyword, question("q26b") var("street") strings(`"street"')
keyword, question("q26b") var("reconstruct") strings(`"reconstruct"')
keyword, question("q26b") var("air_port") and1(`"air"') and2(`"port"')
keyword, question("q26b") var("locomotion") strings(`"locomotion"')
keyword, question("q26b") var("vehicle") strings(`"vehicle"')
keyword, question("q26b") var("transit") strings(`"transit"')
keyword, question("q26b") var("route") strings(`"route"')
keyword, question("q26b") var("mobility") strings(`"mobility"')
keyword, question("q26b") var("cars") strings(`"car"') not(`" "care" "')
keyword, question("q26b") var("drive") strings(`"drive"')
keyword, question("q26b") var("taxi") strings(`"taxi"')
keyword, question("q26b") var("construction") strings(`"construct"')
keyword, question("q26b") var("buildings") strings(`"building"')
keyword, question("q26b") var("estate") strings(`"estate"') not(`" "real" "')
keyword, question("q26b") var("motor") strings(`"motor"')
keyword, question("q26b") var("traffic") strings(`"traffic"')
keyword, question("q26b") var("bridge") strings(`"bridge"')
keyword, question("q26b") var("pavement") strings(`"pavement"')
keyword, question("q26b") var("foot_path") and1(`"foot"') and2(`"path"')
keyword, question("q26b") var("mrt") strings(`"mrt"')
keyword, question("q26b") var("brt") strings(`"brt"')
keyword, question("q26b") var("rapid") strings(`"rapid"')
keyword, question("q26b") var("sanitation") strings(`"sanita"')
keyword, question("q26b") var("toilet") strings(`"toilet"')
keyword, question("q26b") var("water") strings(`"water"')
keyword, question("q26b") var("drainage") strings(`"drainage"')
keyword, question("q26b") var("waste reduction") strings(`"`"wastage"' `"waste reduc"'"')
keyword, question("q26b") var("garbage") strings(`"garbage"')
keyword, question("q26b") var("electricity") strings(`"electric"') not(`" `"system"' "')
keyword, question("q26b") var("fuel") strings(`"fuel"')
keyword, question("q26b") var("gas") strings(`"gas"')
keyword, question("q26b") var("petrol") strings(`"petrol"')
keyword, question("q26b") var("reduce bills") and1(`"reduc"') and2(`"bill"')
keyword, question("q26b") var("light") start(`"light"')



*Country name (for overall development):
levelsof country
foreach c in `r(levels)' {
	local c=upper("`c'")
	
	replace kw_on_the_country=1 if q26b =="`c'"
	replace kw_on_the_country=1 if strpos(q26b,"`c'")==1
	replace kw_on_the_country=1 if strpos(q26b,"`c'") & strpos(q26b,"CITIZEN")
	replace kw_on_the_country=1 if strpos(q26b,"`c'") & strpos(q26b,"PEOPLE")
	
	replace kw_young_people=1 if strpos(q26b,"`c'") & strpos(q26b,"YOUNG")
	
}
	
foreach c in "ANGOLANS" "ARGENTINES" "BANGLADESHIS" "BOLIVIANS" "ECUADORIANS" "EGYPTIANS" "GHANIANS" "INDONESIANS" "KAZAKHS" "NIGERIANS" "PAKISTANIS" "VIETNAMESE" {
	
	replace kw_on_the_country=1 if q26b =="`c'"
	
	//Country+people
	local c=substr("`c'", 1, length("`c'") - 1)
	di "`c'"
	replace kw_for_the_people=1 if strpos(q26b ,"`c'") & strpos(q26b ,"PEOPLE")
	
	
}	
	
*Variable that lists all keywords:
gen identified_keywords_26b=""
ds kw_*
foreach var in `r(varlist)' {
	local lab: variable label `var'
	local lab=subinstr("`lab'","Keyword (q26b): ","",.)
	replace identified_keywords_26b=identified_keywords_26b+"`lab', " if `var'==1
}
replace identified_keywords_26b = substr(identified_keywords_26b, 1, length(identified_keywords_26b) - 2)

label var identified_keywords_26b "Keywords identified in Q26b"
format %50s identified_keywords_26b


*Groupings:
theme, name(community)	  vars(kw_parks-kw_playground) 						desc("Community & social spaces")
theme, name(huamnitarian) vars(kw_disaster-kw_visa)							desc("Humanitarian response")
theme, name(development)  vars(kw_economic_development-kw_remote) 			desc("Economic development")
theme, name(education) 	  vars(kw_education-kw_literacy) 					desc("Education")
theme, name(care) 	  	  vars(kw_elderly-kw_kindergarten)  				desc("Child & elderly care")
theme, name(employment)   vars(kw_job-kw_career) 							desc("Employment creation")
theme, name(environment)  vars(kw_environment-kw_climate) 					desc("Environment")
theme, name(agriculture)  vars(kw_food-kw_fruits)							desc("Food & agriculture")
theme, name(governance)   vars(kw_governance-kw_transparency) 				desc("Governance")
theme, name(health) 	  vars(kw_health-kw_maternity)						desc("Health")
theme, name(housing) 	  vars(kw_housing-kw_apartment) 					desc("Housing")
theme, name(powmgmt)   	  vars(kw_electrical_system-kw_power_generation) 	desc("Improve power management")
theme, name(inflation) 	  vars(kw_inflation-kw_devaluation) 				desc("Price control")
theme, name(natural) 	  vars(kw_mineral-kw_iron)							desc("Natural resources")
theme, name(nation) 	  vars(kw_for_the_people-kw_on_the_country)			desc("National welfare")
theme, name(poverty) 	  vars(kw_poverty-kw_suffering)						desc("Poverty reduction")
theme, name(security) 	  vars(kw_safety-kw_law_order) 						desc("Public safety")
theme, name(renewables)   vars(kw_renewable-kw_energy_saving) 				desc("Renewable energy")
theme, name(safetynets)   vars(kw_cash-kw_social_security) 					desc("Safety nets")
theme, name(taxes) 	 	  vars(kw_tax-kw_gst) 								desc("Tax relief")
theme, name(technology)	  vars(kw_technology-kw_digital) 					desc("Technology")
theme, name(industry) 	  vars(kw_trade-kw_steel) 							desc("Industry & trade")
theme, name(transport) 	  vars(kw_transport-kw_rapid) 						desc("Transport & infrastructure")
theme, name(water)   	  vars(kw_sanitation-kw_garbage) 					desc("Water & sanitation")
theme, name(electricity)  vars(kw_electricity-kw_light) 					desc("Electricity and fuel")


*Use any keword:
egen any_kw_26b=rowmax(kw_*)
label var any_kw_26b "Mention any of the identified keywords in Q26b"
label values any_kw_26b yn
tab any_kw_26b

	
*Comments that do no address the question:
gen other_comments=0 if q26b!=""
foreach i in "YES" "YEAH" "NO" "OK" "OKAY" "NA" "GOOD" "AGREE" "AGREED" "DISAGREE" "SUPPORT" "SUBSIDIES" "SUBSIDY" {
	replace other_comments=1 if any_kw_26b==0 & inlist(q26b,"`i'")
}

replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"NOTHING")==1
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"DON") & strpos(q26b,"KNOW")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"DON") & strpos(q26b,"UNDER")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"NO") & strpos(q26b,"COMMENT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"NO") & strpos(q26b,"ANSWER")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"NO") & strpos(q26b,"SURE")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"NO") & strpos(q26b,"IDEA")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"YES") & strpos(q26b,"AGREE")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"DO") & strpos(q26b,"SUPPORT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"YES") & strpos(q26b,"SUPPORT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"WOULD") & strpos(q26b,"SUPPORT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"I") & strpos(q26b,"SUPPORT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"I") & strpos(q26b,"AGREE")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"STRONG") & strpos(q26b,"AGREE")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"STRONG") & strpos(q26b,"SUPPORT")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"THANK") & strpos(q26b,"YOU")
replace other_comments=1 if any_kw_26b==0 & strpos(q26b,"WILL") & strpos(q26b,"DO")

	label var other_comments "Comments that do not address the question"
	label values other_comments yn

tab other_comments
tab any_kw_26b if q26b!="" & other_comments==0

*Comments that don't mention electricity or fuel:
egen non_elec_comments=rowmax(th_community-th_water)
label var non_elec_comments "Comments that mention non-electricity keywords"
label values non_elec_comments yn

*Full marker
gen 	tab_26b=.
replace tab_26b=0 if q26b==""
replace tab_26b=1 if non_elec_comments==1
replace tab_26b=2 if non_elec_comments==0 & th_electricity==1
replace tab_26b=3 if other_comments==1 & any_kw_26b==0
replace tab_26b=4 if other_comments==0 & any_kw_26b==0

label define tab_26b ///
0 "Q26b is blank" ///
1 "Mention identified keywords in Q26b" ///
2 "Mention only electricity and fuel in Q26b" ///
3 "Unrelated comments" ///
4 "All other cases" , modify
label values tab_26b tab_26b

tab tab_26b if !inlist(tab_26b,0)
tab tab_26b if !inlist(tab_26b,0,3)
tab tab_26b if !inlist(tab_26b,0,3,4)


************************************* Q31 **************************************

*Identify keywords:
keyword, question("q31") var("nope") only(`"nope"')
keyword, question("q31") var("no bias") only(`"no"')
keyword, question("q31") var("not at all biased") strings(`"`"not at all"'"')
keyword, question("q31") var("is not") only(`"`"are not"'"')
keyword, question("q31") var("unbiased") strings(`"`"unbias"' `"un bias"' `"not bias"' `"no bias"' `"unbias"' `"not bias"' `"no bias"' `"less bias"' `"isnt any bias"' `"isnt bias"'"')
keyword, question("q31") var("all inclusive") strings(`"`"all inclusive"' "')
keyword, question("q31") var("impartial") strings(`"`"impartial"' `"not partial"' "')
keyword, question("q31") var("only fair") only(`"fair"')
keyword, question("q31") var("a fair survey") strings(`"`"fairly well"' `"fairly good"'  `"very fair"' `"is fair"'  `"was fair"' `"but fair"' `"fair enough"' `"very fair"' `"fair survey"' `"free and fair"' "') not(`" `"not fair"'  `"not very fair"' `"government"' `"electricity"'  "')
combine_kw, vars(kw_only_fair-kw_a_fair_survey) name(kw_a_fair_survey)
keyword, question("q31") var("objective") strings(`"`"objective"'"') not(`" `"not obj"' `"unobj"' `"un obj"' `"objectives"' "')
keyword, question("q31") var("reliable") strings(`"`"reliable"'"') not(`" `"subsidy"'  `"mechanism"'  `"subsid"' `"country"' `"more reliable"' `"not seem reliable"'  "')
keyword, question("q31") var("balanced") strings(`"balanced"') not(`" `"not balance"'  `"unbalance"'  `"imbalance"'  "')

keyword, question("q31") var("meaningful") strings(`"meaningful "') not(`" `"not meaning"' "')
keyword, question("q31") var("rewarding") strings(`"rewarding "') not(`" `"not rew"' "')
keyword, question("q31") var("beneficial") strings(`"`"benefic"' `"benefited"' "') not(`" `"not benef"' "')
keyword, question("q31") var("valuable") strings(`"valuable"') not(`" `"not valuable"' "')
keyword, question("q31") var("fruitful") strings(`"fruitful"') not(`" `"not fruitfu"' `"unfruit"'  "')

keyword, question("q31") var("correct poll") and1(`"correct"') and2(`"`"survey"' `"poll"' `"seems"' `"found it"' `"everything is"' `"and discreet"'"')
keyword, question("q31") var("logical") strings(`"`"logical"'   "') not(`"  `"illogical"' `"not logical"' `"no logical"' `"ecological"' `"ideological"'  `"psych"'  `"gover"' `"subsid"' `"techno"'  "')
keyword, question("q31") var("factual") strings(`"`"fact survey"'"')
keyword, question("q31") var("realistic") strings(`"`"realistic"'"') not(`" `"not realistic"' `"unrealistic"'  "')
keyword, question("q31") var("reasonable") strings(`"reasonable"') not(`" `"not reasonable"'  `"unreasonable"' "')
keyword, question("q31") var("accurate") strings(`"`"accurate"'   "') not(`"  `"not"'  "')
keyword, question("q31") var("reflection of reality") strings(`"`"reality"'   "') not(`"  `"not"'  "')

keyword, question("q31") var("hope for more") and1(`"hope"') and2(`"`"again"' `"more"'"')
keyword, question("q31") var("want more polls") strings(`"`"more polls"' `"more like this"'  `"like to see more"'   "')
keyword, question("q31") var("continue") strings(`"continue"') not(`" `"subsid"' `"corrupt"' `"not conti"' `"disconti"' `"induc"'  "')
keyword, question("q31") var("reach more people") and1(`"reach"') and2(`" `"people"' "') not(`" `"government"' `"not reach"' `"dont reach"'  "')
keyword, question("q31") var("want more surveys") and1(`"more"') and2(`" `"want"' `"survey"'  "') not(`" `"subsid"' `"electr"' `"fuel"' `"countr"' `"gover"' `"citizen"' `"job"' `"dont"' `"anymore"' `"no more"' `"pay more"' `"earn more"'   `"detail"' `"specific"' `"option"' `"choice"'  `"more people"' `"more comphrensive"' "')
keyword, question("q31") var("keep it up") and1(`"keep"') and2(`"`"up"' "')
keyword, question("q31") var("keep going") only(`"`"keep going"'"')

keyword, question("q31") var("thoughtful") strings(`"`"thoughtful"' `"thought ful"'"') not(`" `"not thought"'  "')
keyword, question("q31") var("well designed") strings(`"`"well design"'"')
keyword, question("q31") var("well formulated") strings(`"`"formulate"'"') not(`" `"not well form"'  "')
keyword, question("q31") var("professional") strings(`"profes"') not(`" `"not prof"' `"unprof"' `"should"' `"would"' `"young"' `"subsid"'  "')
keyword, question("q31") var("quality survey") strings(`"quality"') not(`" `"bad quality"' `"not quality"' `"life"' `"improv"' `"increase"' `"gover"' `"equality"' `"gover"'  "')
keyword, question("q31") var("only well") only(`"well"')
keyword, question("q31") var("well posed") strings(`"`"well posed"' "')
keyword, question("q31") var("well done survey") strings(`"`"well done"' `"very well"'  `"really well"' `"done well"'  `"well formulated"' `"fairly well"' `"already well"' `"all is well"' `"all was well"' "') not(`" `"payment"'  `"know very well"'   `"currency"'  `"earning"'   "')
combine_kw, vars(kw_only_well-kw_well_done_survey) name(kw_well_done_survey)
keyword, question("q31") var("constructive") strings(`"construct"') not(`" `"unconsruct"' `"not construct"'  "')

keyword, question("q31") var("able to express opinion") and1(`"express"') and2(`"`"opinion"'  `"feel"' `"mind"' `"think"' `"view"' `"freedom"' "')

keyword, question("q31") var("comfortable") strings(`"comfort"') not(`" `"uncom"' `"less comf"'  `"not comf"'  `"discomf"' "')
keyword, question("q31") var("cool") strings(`"cool"') not(`" `"uncool"' `"not cool"'  "')
keyword, question("q31") var("helpful") strings(`"helpf"') not(`" `"not help"' `"unhelp"'  "')
keyword, question("q31") var("pleasant") strings(`"`"pleasant"'"')

keyword, question("q31") var("helps understand") strings(`"`"better understand"' `"better idea"' `"help understand"' `"helps understand"'"')
keyword, question("q31") var("informative") strings(`"`"informative"'"') not(`" `"not informative"'  "')
keyword, question("q31") var("creates awareness") strings(`"awareness"')
keyword, question("q31") var("educative") strings(`"`"educative"' `"educational"' `"educating"' "') not(`" `"level"'   `"subsidy"'   `"electri"'  `"gover"'   `"not educ"'   "')
keyword, question("q31") var("reflective") strings(`"reflect"') not(`" `"not reflect"'  "')
keyword, question("q31") var("helps improve") and1(`"help"') and2(`"`"improve"' "')
keyword, question("q31") var("insightful") strings(`"`"insightful"' "') not(`"  `"not insightful"'  "')
keyword, question("q31") var("inspiring") strings(`"inspir"')
keyword, question("q31") var("enlightening") strings(`"`"enlighten"' "') not(`"  `"living condition"'  "')
keyword, question("q31") var("impactful") strings(`"impactful"')
keyword, question("q31") var("adds to knowledge") and1(`"knowledge"') and2(`"`"add"'  `"crucial"' `"gain"' `"give"' `"able"' `"benefit"' `"full"'  `"provide"' `"people"' `"know"' `"increase"' `"open"' `"acquire"' "')

keyword, question("q31") var("hope it helps") and1(`"hope"') and2(`"`"help"' "')
keyword, question("q31") var("hope its used") and1(`"hope"') and2(`"`"use"' "')
keyword, question("q31") var("reach the government") and1(`"reach"') and2(`"`"gov"' `"author"'"')
keyword, question("q31") var("hope the government") and1(`"hope"') and2(`"`"gov"' `"author"'"')
keyword, question("q31") var("hope it counts") and1(`"hope"') and2(`"`"count"' "')
keyword, question("q31") var("hope for good") and1(`"hope"') and2(`"`"good"' `"benef"' "')
keyword, question("q31") var("hope for the best") and1(`"hope"') and2(`"`"better"'  `"best"' "')
keyword, question("q31") var("hope it reaches") and1(`"hope"') and2(`"`"each"' "')
keyword, question("q31") var("hope for change") and1(`"hope"') and2(`"`"change"' `"diff"' "')

keyword, question("q31") var("good") strings(`"`"good"' `"acha"'  "') not(`" `"not good"' `"no good"' `"initiative"'  `"ould"' `"subsidies are good"' `"good citizen"' "')
keyword, question("q31") var("not bad") strings(`"`"not bad"' `"no bad"' `"not too bad"' `"no feedback or bad"' "')
keyword, question("q31") var("positive") strings(`"positi"') not(`" `"not posit"'  "')
keyword, question("q31") var("nice") strings(`"`"nice"'"') not(`" `"not nice"'  "')

keyword, question("q31") var("enjoyed") strings(`"enjoy"') not(`" `"not enjoy"' "')
keyword, question("q31") var("engaging") strings(`"engag"') not(`" `"not engag"' `"unengag"'  "')
keyword, question("q31") var("interesting") strings(`"interest"') not(`" `"not int"' `"unint"' `"no int"' "')
keyword, question("q31") var("fun") exact(`"fun"')
keyword, question("q31") var("glad") strings(`"`"glad"'  "') not(`" `"will be glad"' `"would be glad"' `"bangladesh"'  "')
keyword, question("q31") var("happy") strings(`"`"happiness"'  `"happy"'  `"i am happy"'  `"i am very happy"' "') not(`" `"will be happy"' `"will be more than happy"' `"will be very happy"'  `"unhappy"' `"not happy"' `"country"'  "')
keyword, question("q31") var("worthwhile") strings(`"`"worth"'"') not(`" `"worthless"'  `"trust worthy"'  `"subsid"' `"political"'  "')
keyword, question("q31") var("liked") strings(`"like"') not(`" `"dislike"' `"dis like"' `"not like"' `"no like"' `"dont like"' `"unlike"' `"like to see"' "')

keyword, question("q31") var("timely") strings(`"timely"') not(`" `"not timely"'  "')
keyword, question("q31") var("short") strings(`"short"') not(`" `"not short"' `"snt"' `"rent"' `"shorte"'  "')
keyword, question("q31") var("fast") strings(`"fast"') not(`" `"not fast"' "')
keyword, question("q31") var("brief") strings(`"brief"') not(`" `"not brief"'  `"ould"' "')
keyword, question("q31") var("quick") strings(`"quick"') not(`" `"not quick"'  `"quickly"' "')
keyword, question("q31") var("to the point") strings(`"`"to the point"'"') not(`" `"not to"'  `"must"' `"should"' "')
keyword, question("q31") var("direct") strings(`"direct"') not(`" `"directed"'  `"not direct"' `"direct impact"' "')
keyword, question("q31") var("compact") strings(`"compact"')
keyword, question("q31") var("enough") only(`"enough"')
keyword, question("q31") var("precise") strings(`"`"precise"'"') not(`" `"not precise"' `"imprecise"'  `"less precise"'  `"precisely"'  "')
keyword, question("q31") var("specific") strings(`"`"specific"'"') not(`" `"more"' `"less"' `"quest"' `"less"' `"not very"' `"not"' `"ould"'  "')

keyword, question("q31") var("outstanding") strings(`"`"outstand"' "')
keyword, question("q31") var("awesome") strings(`"awesome"') not(`" `"not awesome"' `"awesome situation"'  "')
keyword, question("q31") var("loved") strings(`"love "') not(`" `"not love"' "')
keyword, question("q31") var("super") exact(`"`"super"' "') not(`" `"superb"' `"elec"'  `"subsid"'  `"harmon"'  `"shop"'  "')
keyword, question("q31") var("great") strings(`"`"great"' "') not(`" `"not great"' `"greatly"'  `"great caution"' `"country"' "')
keyword, question("q31") var("superb") strings(`"`"superb"'"')
keyword, question("q31") var("fantastic") strings(`"`"fantastic"'"')
keyword, question("q31") var("exceptional") strings(`"`"exceptional"'"')
keyword, question("q31") var("brilliant") strings(`"brilliant"')
keyword, question("q31") var("excellent") strings(`"excellent"')
keyword, question("q31") var("wonderful") strings(`"wonderful"') not(`" `"not wond"'  "')
keyword, question("q31") var("beautiful") strings(`"`"beautiful"'"') not(`" `"not beautiful"'  "')
keyword, question("q31") var("amazing") strings(`"amaz"') not(`" `"not amaz"'  "')
keyword, question("q31") var("perfect") strings(`"perfect"') not(`" `"not perfect"' `"imperfect"' `"perfectly"'  "')
keyword, question("q31") var("best") only(`"best"')
keyword, question("q31") var("best survey") and1(`"best"') and2(`"`"quest"' `"answer"' `"survey"' `"love"' `"like"' "')
combine_kw, vars(kw_best-kw_best_survey) name(kw_best_survey)

keyword, question("q31") var("important survey") strings(`"importan"') not(`" `"not import"'  `"subsidy"'  `"government"' `"state"'  `"society"' "')
keyword, question("q31") var("pertinent topic") strings(`"pertinent"')
keyword, question("q31") var("relatable") strings(`"relatable"') not(`" `"not relatable"'  "')
keyword, question("q31") var("essential") strings(`"`"essential"'  "') not(`" `"not essential"'  "')
keyword, question("q31") var("necessary") strings(`"`"necessary"'  "') not(`" `"not neces"'  `"unneces"'  `"gover"'   `"state"'   `"elec"' `"subsid"'  `"necessary to hear"'  `"necessary to support"'    `"necessary for"'   `"necessary to change"'   `"whenever necessary"'    `"poor"'   "')
keyword, question("q31") var("useful") strings(`"`"useful"'"') not(`" `"not useful"'  "')
keyword, question("q31") var("practical") strings(`"practical"') not(`" `"not practical"' `"impractical"'  "')
keyword, question("q31") var("valid") strings(`"valid"') not(`" `"country"' `"subsid"'  "')
keyword, question("q31") var("applicable") strings(`"applicable"') not(`" `"not applicable"' "')
keyword, question("q31") var("agree with survey") and1(`"survey"') and2(`" `"agree with"' "') not(`" `"not"'  "')
keyword, question("q31") var("appropriate") strings(`"`"appropriate survey"' `"is appropriate"' "')
keyword, question("q31") var("relevant") strings(`"relev"') not(`" `"not relev"' `"no relev"' `"irrelev"' "')

keyword, question("q31") var("not difficult") strings(`"`"not difficult"' `"not too difficult"' `"not that difficult"' "')
keyword, question("q31") var("easy") strings(`"`"easy"'"') not(`" `"not easy"'  "')
keyword, question("q31") var("simple") strings(`"simple"') not(`" `"not simple"' `"simpler language"'  "')
keyword, question("q31") var("clear") strings(`"`"clear"'"') not(`" `"unclear"' `"be clear"'  `"more clear"'  `"not clear"'  `"nt clear"'  `"ould"' `"nuclear"' `"made clear"'  `"clearer"'   `"wasnt clear"' `"wasnt quite clear"'  `"wasnt very clear"'  "')
keyword, question("q31") var("straightforward") strings(`"`"straight forward"' `"straightforward"' "')

keyword, question("q31") var("distinct") strings(`"`"distinct"'"') not(`" `"not dist"'  "')
keyword, question("q31") var("good initiative") strings(`"initiative"') not(`" `"bad initiative"'  "')
keyword, question("q31") var("unique") strings(`"unique"')
keyword, question("q31") var("innovative") strings(`"innov"')
keyword, question("q31") var("eye opening") strings(`"`"eye open"'"')
keyword, question("q31") var("exciting") strings(`"exciting"')
keyword, question("q31") var("much needed") strings(`"`"much need"'"')
keyword, question("q31") var("new experience") and1(`"experi"') and2(`"`"new"' `"novel"' `"fresh"'"')

keyword, question("q31") var("yes its biased") start(`"yes"')
keyword, question("q31") var("yeah") only(`"yeah"')
keyword, question("q31") var("of course its biased") strings(`"`"of course"'"') not(`" `"of course not"' "')
keyword, question("q31") var("right") only(`"right"')
keyword, question("q31") var("biased") strings(`"bias"') not(`" `"unbias"' `"un bias"' `"not bias"' `"no bias"' `"less bias"' `"isnt"' "')
keyword, question("q31") var("partial") strings(`"`"partial"' `"directed"'"') not(`" `"impartial"' `"not partial"' "')
keyword, question("q31") var("only agree") only(`"agree"')
keyword, question("q31") var("agreement") only(`"agreement"')
keyword, question("q31") var("agreed") strings(`"`"agreed"' `"i agree"' `"fully agree"' `"somewhat agree"' `"dont object"'  `"fully agree"' "') not(`" `"not agree"' `"disagree"'`"nt agree"' "')
combine_kw, vars(kw_only_agree-kw_agreed) name(kw_agreed)
keyword, question("q31") var("only correct") only(`"correct"')
keyword, question("q31") var("correct there is bias") and1(`"correct"') and2(`"`"seems"' `"everything"' `"somewhat"' `"found"'"')
combine_kw, vars(kw_only_correct-kw_correct_there_is_bias) name(kw_correct_there_is_bias)
keyword, question("q31") var("no doubt") strings(`"`"no doubt"' `"little doubt"' `"without doubt"' `"not doubt"' `"undoubt"' `"any doubt"' `"do not have doubt"' `"wont doubt"'  `"no question"'  "')
keyword, question("q31") var("lot of politics") strings(`"`"lot of politics"'"')
keyword, question("q31") var("suspicious") strings(`"suspic"')
keyword, question("q31") var("induce response") strings(`"induce"')
keyword, question("q31") var("not neutral") and1(`"neutral"') and2(`"`"not"' `"ould"' "')
keyword, question("q31") var("aimed") only(`"`"the survey was aimed"'"')
keyword, question("q31") var("propaganda") strings(`"propag"')
keyword, question("q31") var("intentional") strings(`"`"intentional"'"') not(`" `"not"' "')
keyword, question("q31") var("political survey") strings(`"`"political"'"') not(`" `"gover"' `"management"' `"organi"' `"part"'  `"corrupt"' `"situation"' `"angola"' `"didnt"' `"problem"' `"soci"'  "')

keyword, question("q31") var("too long") strings(`"`"long"' `"lengthy"' `"long time"'  "') not(`" `"not long"' `"long live"'  "')
keyword, question("q31") var("time consuming") and1(`"time"') and2(`" `"cons"' "') not(`" `"not"' `"snt"' "')
keyword, question("q31") var("shorten it") strings(`"`"make it short"' `"keep it short"' `"shorter"'  "') not(`" `"not shorter"'  "')
keyword, question("q31") var("many questions") and1(`"quest"') and2(`" `"reduc"' `"many"' `"refrain"' `"fewer"' `"pointless"' `"less detail"' `"a lot of"' "') not(`"  `"not many"' `"snt many"'  `"rent many"' `"subsid"' "')
keyword, question("q31") var("questions repeating") and1(`"quest"') and2(`"`"repea"'"')
keyword, question("q31") var("not brief") and1(`"brief"') and2(`"`"not"' `"ould"'"')
keyword, question("q31") var("weighty") start(`"weighty"')
keyword, question("q31") var("boring") strings(`"boring"') not(`" `"subsid"' "')
keyword, question("q31") var("repetitive") strings(`"repet"')

keyword, question("q31") var("dislike") strings(`"`"dislike"' `"dis like"' `"not like"' `"no like"' `"dont like"'"')
keyword, question("q31") var("poorly conducted") and1(`"poorly"') and2(`"`"focused"' `"conducted"' "')
keyword, question("q31") var("waste of time") and1(`"time"') and2(`" `"waste"' "') not(`" `"not"' `"snt"' "')
keyword, question("q31") var("only useless") only(`"useless"')
keyword, question("q31") var("found it useless") strings(`"`"not useful"' `"found it useless"' "') not(`" `"not useless"'   "')
combine_kw, vars(kw_only_useless-kw_found_it_useless) name(kw_found_it_useless)
keyword, question("q31") var("unusual") strings(`"unusual"')
keyword, question("q31") var("uncomfortable") strings(`"uncomfort"')
keyword, question("q31") var("a little strange") strings(`"`"strange"'  "') not(`"  `"suffer"'   "')
keyword, question("q31") var("invasive") strings(`"invasiv"')
keyword, question("q31") var("weird") strings(`"weird"')
keyword, question("q31") var("stressful") strings(`"stress"') not(`" `"govern"' `"citizen"'  "')

keyword, question("q31") var("complicated") strings(`"complic"') not(`" `"not complic"' `"uncomplic"'  "')
keyword, question("q31") var("ambiguous") strings(`"ambig"') not(`" `"unamb"' `"less amb"'  `"not amb"' "')
keyword, question("q31") var("technical") strings(`"`"technical"'   "') not(`" `"no technical"'  `"note technical"'  `"technical studies"'  "')
keyword, question("q31") var("complex") strings(`"`"complex"' `"general terms"'  "') not(`" `"issue"'  `"process"'  `"subsid"' `"country"'  "')
keyword, question("q31") var("use simpler questions") and1(`"question"') and2(`"`"simpler"'  `"simplify"'  `"easier"'  "')
keyword, question("q31") var("use simpler language") and1(`"langua"') and2(`"`"simpler"'  `"simplify"'  `"easier"'  `"confus"' `"laymans"' `"using"' `"fluent"' `"difficult"' `"convenient"' `"must be"' `"add"' `"option"'"')
keyword, question("q31") var("confusing") strings(`"confus"')
keyword, question("q31") var("tough") and1(`"tough"') and2(`"`"bit"' `"question"'"')
keyword, question("q31") var("difficult") only(`"difficult"')
keyword, question("q31") var("make clearer") strings(`"`"unclear"' `"be clear"'  `"more clear"'  `"not clear"'  `"nt clear"'  `"ould be clear"'  `"made clear"'  `"clearer"' "')
keyword, question("q31") var("difficult survey") and1(`"difficult"') and2(`" `"quest"' `"answer"' `"survey"' `"complicat"' "') not(`" `"to access"'  "')
combine_kw, vars(kw_difficult-kw_difficult_survey) name(kw_difficult_survey)

keyword, question("q31") var("could be better") and1(`"better"') and2(`" `"ould"' "') not(`" `"subsid"'  `"electricity"'  `"gover"'  `"fuel"' "')
keyword, question("q31") var("be more specific") and1(`"specific"') and2(`"`"more"' `"less"' `"quest"' `"less"' `"not very"' `"not"' `"ould"' "')
keyword, question("q31") var("should be improved") strings(`"`"could be"' `"should be"' `"could have"' `"should have"'  "') not(`" `"done"' `"used"'  `"better"' `"ould benef"' `"specific"'  `"govern"'  `"fuel"'  `"elect"'   `"subsid"'  `"resolved"'   `"situation"'  `"more surveys"'  `"more such surveys"'  `"more of  such"'    `"be equal"'  `"be published"'  `"education"' `"health"'  `"policies"'  `"policy"'  `"be expect"'  `"action"'  `"country"'  `"more partic"' `"survey would be"'   `"invest"'  `"people"' `"more often"' `"knowledge"' "')
keyword, question("q31") var("the survey must") strings(`"`"survey must"'"') not(`" `"convey"'  `"publish"'  "')
keyword, question("q31") var("like to see") strings(`"`"like to see"'"') not(`" `"not like to see"'  "')
keyword, question("q31") var("need to improve quality") and1(`"quality"') and2(`" `"increase"' `"improve"' "') not(`" `"subsid"' `"electr"' `"fuel"' `"countr"' `"gover"' `"life"' `"liv"' "')
keyword, question("q31") var("need more detail") and1(`"more"') and2(`" `"detail"' "') not(`" `"subsid"' "')
keyword, question("q31") var("add more questions") and1(`"more"') and2(`" `"quest"' "') not(`" `"subsid"' "')

keyword, question("q31") var("missing options") and1(`"miss"') and2(`" `"option"' `"choice"' "') not(`" `"subsid"' "')
keyword, question("q31") var("strict") strings(`"strict"') not(`" `"not strict"' `"strictly"'  "')
keyword, question("q31") var("expand options") and1(`"expand"') and2(`" `"option"' `"choice"' "') not(`" `"subsid"' "')
keyword, question("q31") var("limited choice") and1(`"`"limit"'"') and2(`" `"option"' `"choice"' "') not(`" `"fuel is limit"' "')
keyword, question("q31") var("lacking options") and1(`"`"lack of"'"') and2(`" `"option"' `"choice"' "') not(`" `"subsid"' "')
keyword, question("q31") var("increase options") and1(`"`"increase"'"') and2(`" `"option"' `"choice"' "') not(`" `"subsid"' "')
keyword, question("q31") var("need more options") and1(`"more"') and2(`" `"option"' `"choice"' "') not(`" `"subsid"' "')
combine_kw, vars(kw_expand_options-kw_need_more_options) name(kw_need_more_options)

keyword, question("q31") var("thank you") strings(`"`"thank you"' `"thanks"' `"thank"'   `"to thank"'  `"thx"' "') not(`" `"god"'  "')
keyword, question("q31") var("grateful") strings(`"`"grateful"' "') not(`" `"be grateful"'  "')
keyword, question("q31") var("best wishes") and1(`"best"') and2(`"`"luck"' `"wish"' "')
keyword, question("q31") var("congratulations") strings(`"congrat"')
keyword, question("q31") var("god bless") and1(`"god"') and2(`"`"bless"' "')
keyword, question("q31") var("appreciate") strings(`"appreciate"') not(`" `"not appreciate"' `"more"'  "')

keyword, question("q31") var("only neutral") only(`"neutral"')
keyword, question("q31") var("neutral survey") and1(`"neutral"') and2(`"`"survey"' `"position"' `"stance"' `"quest"' `"tendency"' "')
combine_kw, vars(kw_only_neutral-kw_neutral_survey) name(kw_neutral_survey)
keyword, question("q31") var("alright") strings(`"`"alright"' `"all right"' "')
keyword, question("q31") var("only ok") only(`"ok"')
keyword, question("q31") var("only okay") only(`"okay"')
keyword, question("q31") var("survey is ok") strings(`"`"is ok"' `"it ok"'  `"survey ok"'  `"survey was ok"'  `"survey is very ok"'   "')
keyword, question("q31") var("everything is ok") strings(`"`"everything is ok"' `"quite ok"' `"too ok"'  "')
keyword, question("q31") var("okay") start(`"ok"')
keyword, question("q31") var("its okay") strings(`"`"its ok"' `"it is ok"' `"was ok"'  `"all ok"'  `"survey ok"'  `"pretty ok"' "')
combine_kw, vars(kw_only_ok-kw_its_okay) name(kw_okay)
keyword, question("q31") var("only fine") only(`"fine"')
keyword, question("q31") var("survey is fine") and1(`"fine"') and2(`"`"survey"' `"everything"' `"all"' `"its"' `"that"'  `"good"'  `"!"'  `"partly"' "')
combine_kw, vars(kw_only_fine-kw_survey_is_fine) name(kw_survey_is_fine)
keyword, question("q31") var("satisfactory") strings(`"`"satisf"'"') not(`" `"dissatis"' `"unsati"' `"not satis"'  `"country"'  "')
keyword, question("q31") var("moderate") strings(`"`"moderate"'"') not(`"  `"gover"'  `"subsid"' "')
keyword, question("q31") var("normal") strings(`"`"normal"'"') not(`" `"price"' `"abnormal"' `"not normal"'  `"no normal"' `"normally"'  `"gover"'  `"subsid"'  `"cost"' `"country"' `"ould"' `"citizen"'  "')
keyword, question("q31") var("no issue") strings(`"`"no issue"'"') not(`"  `"country"' `"govern"'  "')

keyword, question("q31") var("detailed") strings(`"`"detailed"'"') not(`" `"not detailed"' `"ould"' `"more detailed"'  "')
keyword, question("q31") var("extensive") strings(`"`"extensive"'"')
keyword, question("q31") var("thorough") strings(`"thorough"') not(`" `"not thorough"'  "')
keyword, question("q31") var("comprehensive") strings(`"comprehens"') not(`" `"not comp"' `"ould"' `"much more comprehensive"'  "')

keyword, question("q31") var("no comment") strings(`"`"comment"' `"no word"'  `"no observ"'  `"no opin"' `"no feed"' `"any feed"' `"speechless"'  `"prefer not"' `"i have no"' `"dont have"' `"not necessary"'  `"unnecessary"' `"for now"' `"no response"' `"not now"'   `"not any"' `"isnt any"' `"no need"' `"no notes"'   `"will refrain"'   `"not avail"'  `"null"' "') not(`" `"section"' `"does not exist"'  "')
keyword, question("q31") var("not sure") strings(`"`"not sure"' `"unsure"'  "')
keyword, question("q31") var("dont have anything to say") and1(`"say"') and2(`"`"dont have"' `"dont want"' "')
keyword, question("q31") var("dont know") strings(`"`"not know"' `"dont know"' `"no idea"'   `"do not have"'  "')
keyword, question("q31") var("optional") strings(`"`"optional"'"') not(`" `"not optional"'  "')
keyword, question("q31") var("nil") start(`"nil"')
keyword, question("q31") var("none") start(`"non"')
keyword, question("q31") var("nothing") strings(`"`"nothing"'"') not(`"  `"do nothing"'  "')
keyword, question("q31") var("na") only(`"na"')

*Variable that lists all keywords:
gen identified_keywords_31=""
ds kw_nope-kw_na
foreach var in `r(varlist)' {
	local lab: variable label `var'
	local lab=subinstr("`lab'","Keyword (q31): ","",.)
	replace identified_keywords_31=identified_keywords_31+"`lab', " if `var'==1
}
replace identified_keywords_31 = substr(identified_keywords_31, 1, length(identified_keywords_31) - 2)
label var identified_keywords_31 "Keywords identified in Q31"
format %50s identified_keywords_31


		
*Groupings:
theme, name(unbiased)	 	vars(kw_nope-kw_balanced) 						desc("Unbiased")
theme, name(meaningful)	 	vars(kw_meaningful-kw_fruitful) 				desc("Meaningful")
theme, name(factual)	 	vars(kw_correct_poll-kw_reflection_of_reality) 	desc("Factual")
theme, name(more)	  	 	vars(kw_hope_for_more-kw_keep_going) 			desc("Hope for more")
theme, name(formulated)	 	vars(kw_thoughtful-kw_able_to_express_opinion) 	desc("Well formulated survey")
theme, name(comfortable) 	vars(kw_comfortable-kw_pleasant) 				desc("Comfortable")
theme, name(informative) 	vars(kw_helps_understand-kw_adds_to_knowledge) 	desc("Informative")
theme, name(used)  		 	vars(kw_hope_it_helps-kw_hope_for_change) 		desc("Hope it gets used")
theme, name(good)  		 	vars(kw_good-kw_nice) 							desc("Good survey")
theme, name(enjoyable) 	 	vars(kw_enjoyed-kw_liked) 						desc("Enjoyable")
theme, name(precise)	 	vars(kw_timely-kw_specific) 					desc("Precise")
theme, name(wonderful)   	vars(kw_outstanding-kw_best_survey) 			desc("Wonderful")
theme, name(important)   	vars(kw_important_survey-kw_relevant)		 	desc("An important survey")
theme, name(straight)  	 	vars(kw_not_difficult-kw_straightforward)		desc("Straightforward")
theme, name(new)  		 	vars(kw_distinct-kw_new_experience) 			desc("A new experience")

theme, name(biased)  		vars(kw_yes_its_biased-kw_political_survey) 	desc("Biased")
theme, name(long)  			vars(kw_too_long-kw_repetitive) 				desc("Too long")
theme, name(disliked)     	vars(kw_dislike-kw_found_it_useless) 			desc("Disliked")
theme, name(uncomfortable)	vars(kw_unusual-kw_stressful) 					desc("Uncomfortable")
theme, name(confusing)		vars(kw_complicated-kw_difficult_survey)		desc("Confusing")
theme, name(could)  	  	vars(kw_could_be_better-kw_add_more_questions) 	desc("Could be better")
theme, name(options) 	 	vars(kw_missing_options-kw_need_more_options) 	desc("Need more options")

theme, name(thank) 			vars(kw_thank_you-kw_appreciate) 				desc("Thank you")
theme, name(satisfactory)  	vars(kw_neutral_survey-kw_no_issue) 			desc("Satisfactory")
theme, name(comprehensive) 	vars(kw_detailed-kw_comprehensive) 				desc("Comprehensive")
theme, name(nocomment) 		vars(kw_no_comment-kw_na) 						desc("No comment")


*Category:
egen cat_positive = rowmax(th_unbiased-th_new)
egen cat_negative = rowmax(th_biased-th_options)
egen cat_neutral = rowmax(th_thank-th_nocomment)

label var cat_positive "Positive comments"
label var cat_negative "Negative comments"
label var cat_neutral "Neutral comments"

*venndiag cat_negative cat_positive  cat_neutral

*Full marker
egen 	tab_31=rowmax(th_unbiased-th_nocomment)
recode 	tab_31 (0=2) (.=0)
label define tab_31 ///
0 "Q31 is blank" ///
1 "Mention identified keywords in Q31" ///
2 "Unidentified comments" , modify
label values tab_31 tab_31

tab tab_31 if !inlist(tab_31,0)

sort country_code Vrid
*order country_code country Vrid q1 q2 q3 q26b q31 branch price_treat prime_treat main_treat resp_type* identified_key*
compress
saveold "${datainter}/2. Original responses keywords tagged.dta", replace

