clear
version 17
set more off

//////// SET WORKING DIRECTORY HERE ////////
/*
global path ""

global datain "${path}/Data/Raw"
global dataclean "${path}/Data/Clean/"
global datainter "${path}/Data/Intermediate/"

global dofile "${path}/Dofile"
global figures "${path}/Figures"
global tables "${path}/Tables"
*/
 
********************************************************************************
*Analysis
********************************************************************************
*Programs:
*Save labels:
cap program drop save_labels 
program define save_labels

	qui ds //ind_*
	foreach var in `r(varlist)' {
		cap global lab_`var': variable label `var'
		*di "${lab_`var'}"
	}	
end

*Label indicators
cap program drop label_indicators 
program define label_indicators
	qui ds
	foreach var in 	`r(varlist)' {
		cap label var `var' "${lab_`var'}"		
	}
end

	
*Color macros
	
cap program drop define_colors 
program define define_colors
	global ora "230 159 0"
	global sky "86 180 233"
	global bgr "0 158 115"
	global yel "240 228 66"
	global blu "0 114 178"
	global ver "213 94 0"
	global rpu "204 121 167"
	global bla "0 0 0"
	
	global colors "ver yel bgr sky yel blu ora rpu bla"
	di "$colors"
	
		local n=1
	foreach i in ${colors} {
		global col`n' = "${`i'}"
		
		local n=`n'+1
	}
end	


*Chi-square tests:
cap program drop keyness_test
program define keyness_test

	syntax, negative_group(string) positive_group(string)

	use "${datainter}/3. Frequency table.dta", clear
	
	global negative_group "`negative_group'"
	global positive_group "`positive_group'"

	keep if inlist(group,"${negative_group}","${positive_group}")

	*Make price treatment wide:
	gen j=group
	replace j="_neg" if group=="${negative_group}"
	replace j="_pos" if group=="${positive_group}"

	drop group*

	reshape wide total count prop , i(variable) j(j) string

	egen total_pooled=rowtotal(total*)
	egen count_pooled=rowtotal(count*)

	******* Chi-square tests (manually using formulas) *******

	//Not n-gram:
	foreach i in neg pos pooled {			
		gen not_`i'=total_`i'-count_`i'
	}

	foreach i in neg pos {

		//Just n-grams
			//Expected
			gen exp_ngram_`i'= (count_pooled*total_`i')/total_pooled
			//Obs minus expected
			gen chi2_ngram_`i'= ((count_`i'-exp_ngram_`i')^2)/exp_ngram_`i'
			
		//Including not n-grams
			//Expected
			gen exp_not_ngram_`i'= (not_pooled*total_`i')/total_pooled
			//Obs minus expected
			gen chi2_not_ngram_`i'= ((not_`i'-exp_not_ngram_`i')^2)/exp_not_ngram_`i'		
	}
	//Chi square stat is the sum of all individual deviations:
	egen chi2= rowtotal(chi2_*)
	gen pvalue = chi2tail(1, chi2)

	drop not* exp* chi2_*

	//For all zeros:
	replace chi2=. if chi2==0
	replace pvalue=. if chi2==.

	label var chi2 "|Chi2| (H0: occurrence of keyword is the same across ${negative_group} and ${positive_group})"
	label var pvalue "P-value (Chi2 test)"
			
	isid question variable
	
	replace chi2= chi2*-1 if prop_neg > prop_pos	
end
	
********************************************************************************
*Create a table of all keywords and themes:

use "${datainter}/2. Original responses keywords tagged.dta" , clear
save_labels

//Denominators:
count if q26b!=""
global denomin_pooled=`r(N)'
count if q26b!="" & price_treat==10
global denomin_10=`r(N)'
count if q26b!="" & price_treat==20
global denomin_20=`r(N)'


*Create duplicates for each groups
	*Countries:
	gen group_name="Country: "+country
	gen group=country_code
	
	gen group_type="Countries"
	
	tempfile countries
	save `countries'

	*Main Treat:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	decode main_treat, gen(group_name)
	gen group=lower(group_name)
	
	replace group_name="Main treat: "+group_name
	
	gen group_type="Main treatment"
	
	tempfile main_treat
	save `main_treat'
	
	*Price trreat:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	drop if price_treat==.
	
	gen group_name="Price treat: "+string(price_treat)+"% increase"
	gen group="price"+string(price_treat)
	
	gen group_type="Price treatment"
	
	tempfile price_treat
	save `price_treat'
	
	*Respondent type:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode resp_type_bi, gen(group_name)
	gen group=group_name
	replace group="conditional" if group_name=="Only conditional"
	replace group="rest" if group_name=="The rest"
	
	
	replace group_name="Respondent type: "+group_name
	
	gen group_type="Respondent type"
	
	tempfile resp_type
	save `resp_type'
	
	*Gender:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode q2, gen(group_name)
	gen group=group_name
	replace group="female" if group_name=="Female"
	replace group="male" if group_name=="Male"
	
	
	replace group_name="Gender: "+group_name
	
	gen group_type="Gender"
	
	tempfile gender
	save `gender'
	
	*Trust in government:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode trust, gen(group_name)
	replace group_name = "Trust" 		if strpos(group_name,"Agree")
	replace group_name = "Distrust"  if strpos(group_name,"Disagree")
	
	gen group=lower(group_name)
	
	
	replace group_name="Trust: "+group_name
	
	gen group_type="Trust in government"
	
	tempfile trust
	save `trust'
	
	*Respondent type x Country
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
		//Group name:
	decode resp_type_bi, gen(group_name)
	replace group_name="Respondent type: "+group_name
	
	gen country_group_name="; Country: "+country
	replace group_name=group_name+country_group_name
	drop country_group_name
	
	
		//Group:
	decode resp_type_bi, gen(group)
	replace group="conditional" if group=="Only conditional"
	replace group="rest" 		if group=="The rest"
	
	replace group=group+country_code
	
	
	gen group_type="Respondent type x Country"
	
	tempfile resp_type_country
	save `resp_type_country'	
	
	
	*Age
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	gen group=""
	replace group="below25" if age1824==1
	replace group="above25" if age1824==0
	
	decode age1824, gen(group_name)
	replace group_name="Age: "+group_name
	
	gen group_type="Age"
	
	tempfile age
	save `age'
	
	*Education
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	gen group=""
	replace group="nouniversity" if edu_uni==0
	replace group="university" 	 if edu_uni==1
	
	decode edu_uni, gen(group_name)
	replace group_name="Education: "+group_name
	
	gen group_type="Education"
	
	tempfile education
	save `education'
	
	*Location
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	gen group=""
	replace group="largecity" 		if large_city==1
	replace group="restofcountry" 	if large_city==0
	
	decode large_city, gen(group_name)
	replace group_name="Location: "+group_name
	
	gen group_type="Location"
	
	tempfile location
	save `location'
	
	*Perceived income
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	gen group=""
	replace group="perceivedtop60"	  if pB40==0
	replace group="perceivedbottom40" if pB40==1
	
	decode pB40, gen(group_name)
	replace group_name="Perceived income: "+group_name
	
	gen group_type="Perceived income"
	
	tempfile perceived_income
	save `perceived_income'
	
	*Actual income
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	gen group=""
	replace group="actualtop60"	 	 if B40==0
	replace group="actualbottom40" 	 if B40==1
	
	decode B40, gen(group_name)
	replace group_name="Actual income: "+group_name
	
	gen group_type="Actual income"
	
	tempfile actual_income
	save `actual_income'
	
	*Energy use
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode use_energy, gen(group)
	replace group="subsidized"    if group=="Subsidized user"
	replace group="notsubsidized" if group=="Not subsidized user"
	
	decode use_energy, gen(group_name)
	replace group_name="Energy use: "+group_name
	
	gen group_type="Energy use"
	
	tempfile energy_use
	save `energy_use'	
	
	*Government capacity
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode gov_cap, gen(group)
	replace group="highcapacity"    if group=="High or moderate capacity"
	replace group="lowcapacity" 	if group=="Low or no capacity"
	
	decode gov_cap, gen(group_name)
	replace group_name="Gov capacity: "+group_name
	
	gen group_type="Gov capacity"
	
	tempfile gov_capacity
	save `gov_capacity'	
		
	*Open ended response
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	
	decode open_resp, gen(group)
	replace group="onlyopentextyes"    if group=="Yes"
	replace group="onlyopentextno" 	   if group=="No"
	
	decode open_resp, gen(group_name)
	replace group_name="Only open ended response: "+group_name
	
	gen group_type="Open ended response"
	
	tempfile open_resp
	save `open_resp'	
	
	*Full sample:
	use "${datainter}/2. Original responses keywords tagged.dta" , clear
	gen group_name="*Full sample"
	gen group="*Full"
	
	gen group_type="*Full sample"
	
	append using `countries'
	append using `main_treat'
	append using `price_treat'
	append using `resp_type'
	append using `gender'
	append using `trust'
	append using `resp_type_country'
	append using `age'
	append using `education'
	append using `location'
	append using `perceived_income'
	append using `actual_income'
	append using `energy_use'
	append using `gov_capacity'
	append using `open_resp'
	
//Denominators:
preserve
	gen n=1
	collapse (count) total=n if q26b!="", by(group_type group group_name)
	
	gen question="Q26b"
	
	tempfile totals_26b
	save `totals_26b'
restore
preserve
	gen n=1
	collapse (count) total=n if q31!="",  by(group_type group group_name)
	
	gen question="Q31"
	
	tempfile totals_31
	save `totals_31'
restore

*Collapse keywords and themes seperately:
preserve
foreach x in kw th {
	
	restore
	preserve
	
	*Country, by price_treat:
	collapse (mean) `x'_*, by(group_type group group_name)

	reshape long `x'_, i(group_type group group_name) j(variable) string

	replace variable="`x'_"+variable

	tempfile `x'
	save ``x''
}

restore
clear

append using `kw'
append using `th'

//Combine kw and th:
gen prop=kw_
replace prop=th_ if th_!=.
drop kw th

//Add labels
gen label=""

levelsof variable
foreach i in `r(levels)' {
	replace label="${lab_`i'}" if variable=="`i'"
}


*Identify question:
gen question=""
replace question="Q26b" if strpos(label,"(q26b)")
replace question="Q31"  if strpos(label,"(q31)")


*Split keywords and theme:
split label, p("Theme")
split label2, p(": ")
ren (label1 label22) (keyword theme)
drop label2 label21
replace keyword=subinstr(keyword,"Keyword (q26b): ","",.)
replace keyword=subinstr(keyword,"Keyword (q31): ","",.)
replace keyword=subinstr(keyword,"; ","",.)


//Mark keywords and themes:
gen type=1
replace type=2 if keyword!=""
label define type 1 "Theme" 2 "Keyword"
label values type type 

replace keyword="Theme: "+theme if type==1

label var variable "Variable name"
label var keyword "Keyword"
label var theme "Theme"
label var type "Type"
label var label "Label"


*Generate frequencies:
merge m:1 question group_type group group_name using `totals_26b', nogen 
merge m:1 question group_type group group_name using `totals_31', nogen update replace
 
 
*Gen counts:
gen count=round(total * prop)
	label var count "Count"
	label var prop "Proportion"


*Order and sort
order group* question theme type keyword label variable 
order count prop, last

gsort question group_type group theme type -count

drop label

saveold "${datainter}/3. Frequency table.dta", replace

keep if group=="*Full"
keep if question=="Q31"
gsort type -count


********************************************************************************
*Classification of keywords into themesL
use "${datainter}/3. Frequency table.dta", clear

keep if group=="*Full"
keep if type==2
keep question theme keyword count

label var question "Question #"
label var count "Count"

gsort question theme -count

drop if count==0

export excel using "${tables}/Notes.xlsx", sheet("KW and themes") sheetmodify cell(A1) firstrow(varlabels) keepcellfmt


********************************************************************************
*Summary statistics for strategy success:

use "${datainter}/2. Original responses keywords tagged.dta" , clear

global sheet "Tables D1 and D2"
putexcel set "$tables/Tables D1 and D2.xlsx", sheet("$sheet") modify  //Defining the excel file

*Question 26b:

global row=1
putexcel A${row} =("Table D1: Success rate of linking responses to keywords for Q26b")
global row=${row}+1
putexcel B${row} =(`"Count"')
putexcel C${row} =(`"% of non-missing obs"')
putexcel D${row} =(`"% of all obs"')

global row=${row}+1

putexcel A${row} = ("Linked with at least one keyword")
count if tab_26b==1
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = ("Keywords that mention energy")
count if tab_26b==2
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Unrelated comments"')
count if tab_26b==3
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total linked responses"')
count if inlist(tab_26b,1,2,3)
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total unlinked responses"')
count if tab_26b==4
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total non-missing responses"')
count if inlist(tab_26b,1,2,3,4)
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"No response to Q26b"')
count if tab_26b==0
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total observations"')
count
putexcel B${row}=`r(N)'
global row=${row}+5

*Question 31:
putexcel A${row} =("Table D2: Success rate of linking responses to keywords for Q31")
global row=${row}+1
putexcel B${row} =(`"Count"')
putexcel C${row} =(`"% of non-missing obs"')
putexcel D${row} =(`"% of total obs"')

global row=${row}+1

putexcel A${row} = ("Total linked responses")
count if tab_31==1
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total unlinked responses"')
count if tab_31==2
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total non-missing responses"')
count if inlist(tab_31,1,2)
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"No response to Q31"')
count if tab_31==0
putexcel B${row}=`r(N)'
global row=${row}+1

putexcel A${row} = (`"Total observations"')
count
putexcel B${row}=`r(N)'
global row=${row}+1


********************************************************************************
global figno=0 //start the counter for figure no.
********************************************************************************


********************************************************************************
*CSV Files for wordclouds (themes):

use "${datainter}/3. Frequency table.dta", clear

*Theme classification for Q31
merge m:1 theme using "$datain/q31 theme classification", nogen
replace color="#000000" if color=="" //missing is black

tempfile main
save `main'

*Full sample
use `main', clear
keep if group=="*Full"

	drop if theme=="Electricity and fuel"
	keep if type==1
	keep question keyword count color
	drop if count==0


	replace keyword=subinstr(keyword,"Theme: ","",.)

	//To make things more manegable
	replace count= round(count/10,1)

	preserve
		ren (keyword count) (word weight )
		
		order weight word color
		
		export delimited weight word color using "$figures/CSV/FigureD2_themes_q26b_(Fullsample).csv" if question=="Q26b", replace
		
		global figno=${figno}+1
		export delimited weight word color using "$figures/CSV/FigureD4_themes_q31_(Fullsample).csv" if question=="Q31", replace
		
	restore
	
********************************************************************************
*CSV Files for wordclouds (keywords):

use "${datainter}/3. Frequency table.dta", clear

*Theme classification for Q31
merge m:1 theme using "$datain/q31 theme classification", nogen
replace color="#000000" if color=="" //missing is black

tempfile main
save `main'

*Full sample:
use `main', clear	
keep if group=="*Full"

	drop if theme=="Electricity and fuel"
	keep if type==2
	keep question keyword count color
	drop if count==0

	//To make things more manegable
	replace count= round((count+5)/5,1)

	preserve
		ren (keyword count) (word weight )
		
		order weight word color
		
		export delimited weight word color using "$figures/CSV/Figure9_keywords_q26b_(Fullsample).csv" if question=="Q26b", replace
		
		global figno=${figno}+1
		export delimited weight word color using "$figures/CSV/FigureD3_keywords_q31_(Fullsample).csv" if question=="Q31", replace


	restore
	

********************************************************************************
*Top keywords by country:

*Top themes (Q26B) in each country:
use "${datainter}/3. Frequency table.dta", clear

keep if inlist(group_type,"*Full sample","Countries")
drop if theme=="Electricity and fuel"

replace prop = prop*100

gsort question type group -count
by    question type group: gen rank=_n

gen sample=2 if !inlist(group,"*Full")
replace sample=1 if inlist(group,"AGO","ARG","BOL","ECU","EGY","GHA")

define_colors

preserve
	collapse (mean) prop if question=="Q26b" & group=="*Full" & type==1, by(theme)

	gen have=_n
	sort prop
	gen want=_n

	gen color_no=mod(want-1,7) + 1 
	forval i=1/7 {
	}

	gen bar_color=""
	forval i=1/7 {
	replace bar_color="${col`i'}" if color_no ==`i'
	}

	gen command=""
	replace command="bar("+ string(have) + " , fcolor(" + `"""'  + bar_color +`"""'  + "%70) lcolor(none%0) )"
	sort have 

	global bar_colors
	forvalues j = 1/`=_N' {
		di `"`=command[`j']'"'
		global bar_colors "${bar_colors} `=command[`j']' "
	}

	di `"$bar_colors"'
restore

/*
graph hbar (sum) prop if question=="Q26b" & type==1 & sample!=. & rank<=10, ///
 over(theme, sort(count) descending label(labsize(tiny))) ///
 nofill asyvars ///
 blabel(name, size(vsmall) position(base) box fcolor(white%0) lcolor(none%0) justification(right)) ///
 ytitle(`"% of non-missing observations"', size(2.4)) ///
 by(, note("An observation may be tagged to more than one theme, and threfore the sum of percentages may exceed 100", size(1.6)))  ///
 by(,  title(`"Top themes in Q26b, by country"', size(2.8)))  /// 
 by(, legend(off)) scheme(tab2) xsize(6.5) ysize(9) by(group, noyrescale) ///
 name(top_26b_country, replace)
*/

graph hbar (sum) prop if question=="Q26b" & type==1 & sample!=. & rank<=10, ///
 over(theme, sort(count) descending label(labsize(tiny))) ///
 nofill asyvars ///
 blabel(name, size(vsmall) position(base) box fcolor(white%0) lcolor(none%0) justification(right)) ///
 ytitle(`"% of non-missing observations"', size(2.4)) ///
 by(, note("An observation may be tagged to more than one theme, and threfore the sum of percentages may exceed 100"))  ///
 by(,  title(`"Top themes in Q26b, by country"', size(2.8)))  /// 
 by(, legend(off)) scheme(tab1) xsize(6.5) ysize(9) by(group, noyrescale) ///
 name(top_26b_country, replace)

graph export "$figures/FigureD5.png", replace

 
graph hbar (sum) prop if question=="Q31" & type==1 & sample!=. & rank<=10, ///
 over(theme, sort(count) descending label(labsize(tiny))) ///
 nofill asyvars ///
 blabel(name, size(vsmall) position(base) box fcolor(white%0) lcolor(none%0) justification(right)) ///
 ytitle(`"% of non-missing observations"', size(2.4)) ///
 by(, note("An observation may be tagged to more than one theme, and threfore the sum of percentages may exceed 100"))  ///
 by(,  title(`"Top themes in Q31, by country"', size(2.8)))  /// 
 by(, legend(off)) scheme(tab1) xsize(6.5) ysize(9) by(group, noyrescale) ///
 name(top_26b_country, replace)

 
graph export "$figures/FigureD6.png", replace

********************************************************************************
*Keyness graphs:
********************************************************************************

use "${datainter}/3. Frequency table.dta", clear

****************************** 1. Respondent type ******************************

keyness_test, negative_group(conditional) positive_group(rest)
		

gen chi2_sig = chi2 if pvalue<0.05
gen chi2_insig = chi2 if pvalue>=0.05

label var chi2_sig "p<0.05"
label var chi2_insig "p≥0.05"

graph dot (asis) chi2_sig chi2_insig if type==1 & question=="Q26b", over(theme, sort(chi2) label(labsize(2.2))) ///
ytitle(`"Chi-squared (χ²) statistic"', size(2.3)) ///
ylabel(, labsize(2.2)) ///
marker(1, mcolor(red) msize(1) msymbol(d)) ///
marker(2, mcolor(red) msize(1) msymbol(o)) ///
title("Keyness tests for themes in Q26b, across respondent type", size(2.6)) ///
subtitle("Only conditional support respondent type relative to others", size(2.4)) ///
note(`"Note: This figure shows differences in the relative frequency of alternative policies measures between respondents who unconditionally and only "' ///
`"conditionally support reforms. A positive value indicates a higher frequency among respondents who unconditionally support reforms, and a negative"' ///
`"value indicates a higher frequency among respondents who only conditionally support reforms. The Chi-squared statistic is based on the null hypothesis"' ///
`"that there are no differences between these groups of respondents. It is significant at a p-value of 0.05 if the value falls outside the dotted lines (this is"' ///
`"also marked with a diamond as opposed to a circle)."' , size(1.5)) ///
yline(0, lpattern(dash) lcolor(black%70)) ///
 yline(-3.84, lwidth(thin) lpattern(dash) lcolor(red%70)) ///
 yline(3.84 , lwidth(thin) lpattern(dash) lcolor(red%70)) ///
ylabel(#5) ///
scheme(s1color) ///
legend(rows(1) size(2)) ///
name(keyness_resptype_26b, replace)

graph export "$figures/Figure10.png", replace

************************ 1b. Respondent type x Country *************************
global fignoA=0 //appendix figure

*Country keyness level dataset:

global AGO "Angola"
global ARG "Argentina"
global BGD "Bangladesh"
global BOL "Bolivia"
global ECU "Ecuador"
global EGY "Egypt"
global GHA "Ghana"
global IDN "Indonesia"
global KAZ "Kazakhastan"
global NGA "Nigeria"
global PAK "Pakistan"
global VNM "Vietnam"

use "${datainter}/2. Original responses keywords tagged.dta" , clear
levelsof country_code, local(countries)
global countries "`countries'"
foreach c in $countries {
	
	di "`c'"
	keyness_test, negative_group(rest`c') positive_group(conditional`c')

	gen country_code="`c'"
	gen country="${`c'}"
	
	tempfile resp_`c'
	save `resp_`c''
	

	gen chi2_sig = chi2 if pvalue<0.05
	gen chi2_insig = chi2 if pvalue>=0.05

	label var chi2_sig "p<0.05"
	label var chi2_insig "p≥0.05"


	//Extreme values
	replace chi2_sig=-12 if chi2 <=-12
	replace chi2_sig= 12 if chi2 >= 12 & chi2!=.

	tempfile resp_`c'
	save `resp_`c''

}
clear
foreach c in $countries {
	append using `resp_`c''
}


foreach c in $countries {
	graph dot (asis) chi2_sig chi2_insig if type==1 & question=="Q26b" & country_code=="`c'" ///
	, over(theme, sort(chi2) label(labsize(2.0))) ///
	ytitle(`"Chi-squared (χ²) statistic"', size(2.3)) ///
	marker(1, mcolor(red) msize(1) msymbol(d)) ///
	marker(2, mcolor(red) msize(1) msymbol(o)) ///
	title("${`c'}", size(2.6)) ///
	yline(0, lpattern(dash) lcolor(black%70)) ///
	 yline(-3.84, lwidth(thin) lpattern(dash) lcolor(red%70)) ///
	 yline(3.84 , lwidth(thin) lpattern(dash) lcolor(red%70)) ///
	ylabel(-12 "≤-12" -8 -4 0 4 8 12 "≥12", labsize(1.8)) ///
	scheme(s1color) ///
	legend(rows(1) size(2)) ///
	xsize(3.8) ysize(5.5) ///
	name(keyness_resptype_26b_`c', replace)

}

local n=1
foreach x in ///
"keyness_resptype_26b_AGO keyness_resptype_26b_ARG keyness_resptype_26b_BGD" ///
"keyness_resptype_26b_BOL keyness_resptype_26b_ECU keyness_resptype_26b_EGY" ///
"keyness_resptype_26b_GHA keyness_resptype_26b_IDN keyness_resptype_26b_KAZ" ///
"keyness_resptype_26b_NGA keyness_resptype_26b_PAK keyness_resptype_26b_VNM" ///
 {
 	
	di "`x'"

	grc1leg `x'  ///
	, scheme(s1color) xsize(9) ysize(9) rows(1) ///
	title("Keyness tests for themes in Q26b, across respondent type, by country (`n'/4)", size(2.4)) ///
	subtitle("Only conditional support respondent type relative to others", size(2.2)) ///
	note(`"Note: This figure presents the findings of keyness tests for main themes in responses to Q26b for "' ///
	`"respondents split based on whether they had unconditional or only conditional support for energy "' ///
	`"subsidy reform in each country. A positive value indicates a higher frequency among respondents "' ///
	`"that only conditionally support reforms and a negative value indicates a higher frequency among "' ///
	`"respondents that unconditionally support reforms. The Chi-squared statistic is based on the null "' ///
	`"hypothesis that there are no differences between these groups of respondents. It is significant at "' ///
	`"a p-value of 0.05 if the value falls outside the dotted lines (this is also marked with a diamond "' ///
	`"as opposed to a circle)."' , size(1.5)) ///
	name(keyness_resptype_26b_country`n', replace) imargin(tiny)

	graph export "$figures/FigureD10_`n'.png", replace

	local ++n
}


************************** 2A. Effiency vs Control *****************************

keyness_test, negative_group(control) positive_group(efficiency)
		

gen chi2_sig = chi2 if pvalue<0.05
gen chi2_insig = chi2 if pvalue>=0.05

//Extreme values
replace chi2_sig=-12 if chi2 <=-12
replace chi2_sig= 12 if chi2 >= 12 & chi2!=.

/*
label define chi2 -12 "<-12" 12 "≥12"

label values chi2 		chi2
label values chi2_sig 	chi2
label values chi2_insig chi2
*/

label var chi2_sig "p<0.05"
label var chi2_insig "p≥0.05"

graph dot (asis) chi2_sig chi2_insig if type==1 & question=="Q26b", over(theme, sort(chi2) label(labsize(2.2))) ///
ytitle(`"Chi-squared (χ²) statistic"', size(2.3)) ///
ylabel(, labsize(2.2)) ///
marker(1, mcolor(red) msize(1) msymbol(d)) ///
marker(2, mcolor(red) msize(1) msymbol(o)) ///
title("Keyness tests for themes in Q26b, across main treatment groups", size(2.6)) ///
subtitle("Efficiency relative to control", size(2.4)) ///
note(`"Note: This figure presents the findings of keyness tests for main themes in responses to Q26b for "' ///
`"the efficiency treatment group relative to control group. A positive value indicates a higher fre-"' ///
`"quency among respondents in the efficiency treatment group and a negative value indicates a higher "' ///
`"frequency among respondents in the control group. The Chi-squared statistic is based on the null "' ///
`"hypothesis that there are no differences between these groups of respondents. It is significant at "' ///
`"a p-value of 0.05 if the value falls outside the dotted lines (this is also marked with a diamond as "' ///
`"opposed to a circle)."' , size(1.5)) ///
yline(0, lpattern(dash) lcolor(black%70)) ///
 yline(-3.84, lwidth(thin) lpattern(dash) lcolor(red%70)) ///
 yline(3.84 , lwidth(thin) lpattern(dash) lcolor(red%70)) ///
ylabel(-8 -4 0 4 8 12 ">12") ///
scheme(s1color) ///
legend(rows(1) size(2)) ///
name(keyness_efficiency_26b, replace)

graph export "$figures/FigureD7.png", replace

************************** 2B. Environment vs Control *****************************

keyness_test, negative_group(control) positive_group(environment)
		

gen chi2_sig = chi2 if pvalue<0.05
gen chi2_insig = chi2 if pvalue>=0.05

//Extreme values
replace chi2_sig=-12 if chi2 <=-12
replace chi2_sig= 12 if chi2 >= 12 & chi2!=.

label var chi2_sig "p<0.05"
label var chi2_insig "p≥0.05"

graph dot (asis) chi2_sig chi2_insig if type==1 & question=="Q26b", over(theme, sort(chi2) label(labsize(2.2))) ///
ytitle(`"Chi-squared (χ²) statistic"', size(2.3)) ///
ylabel(, labsize(2.2)) ///
marker(1, mcolor(red) msize(1) msymbol(d)) ///
marker(2, mcolor(red) msize(1) msymbol(o)) ///
title("Keyness tests for themes in Q26b, across main treatment groups", size(2.6)) ///
subtitle("Environment relative to control", size(2.4)) ///
note(`"Note: This figure presents the findings of keyness tests for main themes in responses to Q26b for "' ///
`"the environment treatment group relative to control group. A positive value indicates a higher "' ///
`"frequency among respondents in the environment treatment group and a negative value indicates a "' ///
`"higher frequency among respondents in the control group. The Chi-squared statistic is based on the "' ///
`"null hypothesis that there are no differences between these groups of respondents. It is significant "' ///
`"at a p-value of 0.05 if the value falls outside the dotted lines (this is also marked with a diamond "' ///
`"as opposed to a circle)."' , size(1.5)) ///
yline(0, lpattern(dash) lcolor(black%70)) ///
 yline(-3.84, lwidth(thin) lpattern(dash) lcolor(red%70)) ///
 yline(3.84 , lwidth(thin) lpattern(dash) lcolor(red%70)) ///
ylabel(-12 "≤-12" -8 -4 0 4 8 12 "≥12") ///
scheme(s1color) ///
legend(rows(1) size(2)) ///
name(keyness_environment_26b, replace)


graph export "$figures/FigureD8.png", replace


************************** 2C. Equity vs Control *****************************

keyness_test, negative_group(control) positive_group(equity)
		

gen chi2_sig = chi2 if pvalue<0.05
gen chi2_insig = chi2 if pvalue>=0.05

//Extreme values
replace chi2_sig=-12 if chi2 <=-12
replace chi2_sig= 12 if chi2 >= 12 & chi2!=.

label var chi2_sig "p<0.05"
label var chi2_insig "p≥0.05"

graph dot (asis) chi2_sig chi2_insig if type==1 & question=="Q26b", over(theme, sort(chi2) label(labsize(2.2))) ///
ytitle(`"Chi-squared (χ²) statistic"', size(2.3)) ///
ylabel(, labsize(2.2)) ///
marker(1, mcolor(red) msize(1) msymbol(d)) ///
marker(2, mcolor(red) msize(1) msymbol(o)) ///
title("Keyness tests for themes in Q26b, across main treatment groups", size(2.6)) ///
subtitle("Equity relative to control", size(2.4)) ///
note(`"Note: This figure presents the findings of keyness tests for main themes in responses to Q26b for "' ///
`"the equity treatment group relative to control group. A positive value indicates a higher frequency "' ///
`"among respondents in the equity treatment group and a negative value indicates a higher frequency "' ///
`"among respondents in the control group. The Chi-squared statistic is based on the null hypothesis "' ///
`"that there are no differences between these groups of respondents. It is significant at a p-value of 0.05 "' ///
`"if the value falls outside the dotted lines (this is also marked with a diamond as opposed to a circle)."' , size(1.5)) ///
yline(0, lpattern(dash) lcolor(black%70)) ///
 yline(-3.84, lwidth(thin) lpattern(dash) lcolor(red%70)) ///
 yline(3.84 , lwidth(thin) lpattern(dash) lcolor(red%70)) ///
ylabel(-12 "≤-12" -8 4 0 4 8) ///
scheme(s1color) ///
legend(rows(1) size(2)) ///
name(keyness_equity_26b, replace)

graph export "$figures/FigureD9.png", replace