//Pre Analysis

*importing environmental data
*	2021 environmental data (used for treatments)
import excel using "$predata\Environmental_data_IMF.xlsx", sheet("Spending_enviro_implicitIMF") cellrang(A7:AA91) firstrow clear 
renvars *, lower
drop a b
rename 	count ordernum
rename 	countryname country
replace variablename="" if variablename=="0"
replace variableconcept="" if variableconcept=="0"
destring k-aa, force replace
gen 	subsid_usd = o
la var 	subsid_usd "Subsidy in USD billions"
gen 	subsid_gdp = u
la var 	subsid_gdp "Subsidy in % of GDP"
drop 	k-aa
keep if ordernum>=4 & ordernum<6 
replace subsidy="air_pol" if ordernum==4
replace subsidy="glo_war" if ordernum==5
drop 	variablename variableconcept region source

keep if country=="Angola" | ///
	country=="Argentina"  | ///
	country=="Bangladesh" | ///
	country=="Bolivia"	  | ///
	country=="Ecuador"    | ///
	country=="Egypt" 	  | ///
	country=="Ghana" 	  | ///
	country=="Indonesia"  | ///
	country=="Kazakhstan" | ///
	country=="Nigeria"    | ///
	country=="Pakistan"   | ///
	country=="Vietnam" 

reshape wide subsid_usd subsid_gdp subsidy, i(country) j(ordernum)
rename 	subsid_usd4 air_pol_usd
rename 	subsid_gdp4 air_pol_gdp
rename 	subsid_usd5 glo_war_usd
rename 	subsid_gdp5 glo_war_gdp
tempfile enviro_subsidy
save 	`enviro_subsidy'

* Import treatment data
import excel "$predata\Country level data_Efficiency_Equity.xlsx", sheet("treatment") cellrange(A2:T15) firstrow clear

*Rename variables and clean data
renvars *, lower
rename  totalcostofsubsidiesinbilli energy_lcu
la var energy_lcu "Total cost of subsidies in billions of LCU"
gen energy_year=2021
replace energy_year=2022 if country=="Ghana"
la var energy_year "Year of energy subsidy data"
rename subsidyspending energy_gdp
la var energy_gdp "Total cost of subsidies as sahre of GDP"
rename healthspending health_gdp 
la var health_gdp "Domestic general government health expenditure (% of GDP)"
rename amountinlocalcurrenciesbilli enviro_survey
la var  enviro_survey "Environmental damage in billions of LCU (for survey)"
rename m enviro_damage
la var enviro_damage "2021 Environmental damage in billions of LCU"
la var  fx "Nominal exchange rate LCU x 1USD at May2023"
rename implicitofgdp implicit_subsid 
la var  implicit_subsid "Environm. cost of subsidies (Air Pol. + Glo. Warming) %GDP - IMF"
destring equity_year, replace force
la var equity_year "Year of the equity data"
la var equity_type "Eenergy type (elec/fuel) for equity data"
drop statementseeq20a  ratioq5toq1
drop equity_availability

rename poorest q1
rename g q2
rename h q3
rename i q4
rename richest q5

merge 1:1 country using `enviro_subsidy', keep(3)
drop _merge
egen double enviro_usd=rowtotal(air_pol_usd glo_war_usd)
egen double enviro_gdp=rowtotal(air_pol_gdp glo_war_gdp)

la var enviro_usd "2021 Implicit environmental cost (const 2021 USD B)"
la var enviro_gdp "2021 Implicit environmental cost (% of GDP)"
drop enviro_damage

*__________________________________
* Fig C1 - Efficiency figure

**Countries
graph drop _all
levelsof country, local(ctry_list)
local chartname 
foreach i of local ctry_list {
	local chartname "`chartname' `i'"	
	gr bar energy_gdp health_gdp if country=="`i'", ///
	name(`i', replace) title("`i'", size(large) box bex bc(edkblue*.1)) ///
	graphregion(fcolor(gs16) ifcolor(gs16)) ///
	bar(1, fc(orange) fi(inten30) lc(black) lw(thin)) ///
	bar(2, color(edkblue) lc(black) lw(thin)) ///
	bargap(70) outergap(1) yscale(noline)  ///
	ytitle("% of GDP",orient(vertical) place(r)) ///
	ylab(, angle(0) format(%2.1f)) ///
	yvaroptions(relabel(1 "Energy Subsidy" 2 "Health Spend"))    ///
	showyvars legend(off)  
}	
**Panel
graph combine `chartname', ///
	  imargin(vsmall) cols(4) iscale(0.4) ///
	  ysize(4) xsize(5) graphr(fc(gs16) ifc(gs16) ilc(white)) 
graph export "$figures\FigureC1.png", replace

*__________________________________
*Fig C3 - Environmental figure
	*one figure for all countries 2021
gr bar (asis) air_pol_gdp glo_war_gdp, over(code, sort(implicit_subsid) des) stack ///
	graphregion(fcolor(gs16) ifcolor(gs16)) ///
	ytitle("% of GDP",orient(vertical) place(r)) ///
	ylab(, angle(0) format(%2.0f)) ///
	bar(1, fc(orange) fi(inten30) lc(black) lw(thin)) ///
	bar(2, color(edkblue) lc(black) lw(thin)) ///) ///
	yvaroptions(relabel(1 "Air pollution" 2 "Climate change"))  ///
	yscale(noline range(0 20)) ylabel(0 (5) 25) ///
	legend(rows(2) position(2) ring(0) order(2 1) region(lw(none) fc(none)))

graph export "$figures\FigureC3.png" , replace

*___________________________________
* Fig C2 - Equity figure

*Incidence curves
reshape long q, i(country) j(quintile)
rename q ene_equity
label var ene_equity 	"Concentration share of energy subsidy spending"
label var quintile 		"Income quintiles"

gen confidential=(country=="Angola" | country=="Bangladesh" | country=="Ecuador" | country=="Kazakhstan" | country=="Nigeria" | country=="Nigeria" | country=="Pakistan")

**Countries
graph drop _all
local chartname
levelsof country, local(ctry_list)
foreach i of local ctry_list {
	local chartname "`chartname' `i'"
	twoway connected ene_equity quintile if country=="`i'", ///
	name(`i', replace) title(`i', size(large) box bex bc(edkblue*.1))  ///
	graphregion(fcolor(gs16) ifcolor(gs16) /// 
	ilcolor(white) lc(white))  xtick(1(1)5) xlab(1(1)5) ///
	xtitle("Income quintiles") ///
	ytitle("%",orient(horizontal) place(r)) ylab(, angle(0) format(%2.0f)) /// 
	yscale(noline range(0 80)) ylabel(0 (20) 80) ///
	lc(edkblue) mc(edkblue) aspectr(0.8)   
}

graph combine `chartname', ///
	  imargin(vsmall) cols(3)  iscale(0.45) ///
	  ysize(4) xsize(4) graphr(fc(gs16) ifc(gs16) ilc(white)) 
graph export "$figures\FigureC2.png" , replace

clear